package org.datamanager.collector.helpers.email;

import org.datamanager.collector.helpers.email.BasicWindowMonitor;

import org.datamanager.kernel.Pool;
import org.datamanager.exception.DataManagerException;
import org.datamanager.event.EmailParametersEnteredEvent;
import org.datamanager.tools.Debug;
import org.datamanager.userinterface.cerulean.model.kernel.KernelProxy;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.JLabel;
import javax.swing.JPasswordField;
import javax.swing.JButton;
import javax.swing.JOptionPane;

import java.awt.Container;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.FlowLayout;
import java.awt.BorderLayout;
import java.awt.GridLayout;
import java.awt.event.WindowEvent;
import java.awt.event.WindowAdapter;
import java.awt.Window;

/**
Author: Manoj Shanbhag (mshanbha@cs.indiana.edu)
Group : Networks
Date  : Nov 22, 1998
Modified: December 6, 1999, gregory j. e. rawlins

Collaborators:
BasicWindowMonitor, EmailParametersEnteredEvent

Responsibilities:
Objects of this class display a window for the user to enter parameters
describing the network connection to fetch an email repository.
On completion, it generates an event holding the connection parameters.

The email parameters are: username, password, email host machine, email access
protocol (imap, pop3, and smtp), and mailbox. 
**/

public class EmailParametersInputWindow
	extends JFrame
	implements ActionListener
	{
	private JTextField userNameField;
	private JPasswordField passwordField;
	private JTextField hostMachineField;
	private JTextField accessProtocolField;
	private JTextField mailboxField;

	/**
	Generate a window made up of two panels---one for parameter entry
	and the other for an okay and a cancel button.
	**/
	public EmailParametersInputWindow()
		{
		super("Set email configuration parameters");
		setSize(300, 200);
		addWindowListener(new BasicWindowMonitor());

		//parameters panel////////////////////////////////////////
		JPanel inputParametersPanel = new JPanel();
		inputParametersPanel.setLayout(new GridLayout(5, 2));

		userNameField = new JTextField("mshanbha", 30);
		userNameField.setToolTipText("Type user name");
		JLabel userNameLabel = new JLabel("username");
		inputParametersPanel.add(userNameLabel);
		inputParametersPanel.add(userNameField);
		userNameField.addActionListener(this);

		passwordField = new JPasswordField(30);
		passwordField.setToolTipText("Type password");
		JLabel passwordLabel = new JLabel("password");
		inputParametersPanel.add(passwordLabel);
		inputParametersPanel.add(passwordField);
		passwordField.addActionListener(this);

		hostMachineField = new JTextField("whale", 30);
		hostMachineField.setToolTipText("Type email host name");
		JLabel hostMachineLabel = new JLabel("email host name");
		inputParametersPanel.add(hostMachineLabel);
		inputParametersPanel.add(hostMachineField);
		hostMachineField.addActionListener(this);

		accessProtocolField = new JTextField("imap", 30);
		accessProtocolField.setToolTipText("Type access protocol");
		JLabel accessProtocolLabel = new JLabel("access protocol");
		inputParametersPanel.add(accessProtocolLabel);
		inputParametersPanel.add(accessProtocolField);
		accessProtocolField.addActionListener(this);

		mailboxField = new JTextField("mailbox", 30);
		mailboxField.setToolTipText("Type email mailbox");
		JLabel mailboxLabel = new JLabel("email mailbox");
		inputParametersPanel.add(mailboxLabel);
		inputParametersPanel.add(mailboxField);
		mailboxField.addActionListener(this);

		//buttons panel//////////////////////////////////////////
		JPanel buttonsPanel = new JPanel();
		buttonsPanel.setLayout(new FlowLayout(FlowLayout.CENTER));

		JButton okayButton = new JButton("Okay");
		okayButton.setActionCommand("okay");
		okayButton.addActionListener(this);
		buttonsPanel.add(okayButton);

		JButton cancelButton = new JButton("Cancel");
		cancelButton.setActionCommand("cancel");
		cancelButton.addActionListener(this);
		buttonsPanel.add(cancelButton);

		//add both panels to the frame//////////////////////////
		Container contentPane = getContentPane();
		contentPane.add(inputParametersPanel, BorderLayout.CENTER);
		contentPane.add(buttonsPanel, BorderLayout.SOUTH);
		}

	/**
	Check whether the user pressed the okay or cancel buttons.
	If so, either generate an event containing the email parameters
	and cancel the window, or simply cancel the window.
	**/
	public void actionPerformed(ActionEvent event)
		{
		String command = event.getActionCommand();

		if (command.equals("okay"))
			{
			try
				{
				Pool pool = Pool.getDefaultPool();
				EmailParametersEnteredEvent mailEvent =
					new EmailParametersEnteredEvent(pool,
					userNameField.getText(),
					passwordField.getText(),
					hostMachineField.getText(),
					accessProtocolField.getText(),
					mailboxField.getText());
				KernelProxy.getInstance().addEvent(mailEvent);
				//NOTE: hack. kernelProxy should be a general
				//tool for all interfaces, not specific only
				//to cerulean
				}
			catch (DataManagerException exception)
				{
				Debug.assert("bug in kernel!");
				exception.printStackTrace();
				}

			this.setVisible(false);
			this.dispose();
			}
		else if (command.equals("cancel"))
			{
			this.setVisible(false);
			this.dispose();
			}
		}

	/**
	To test this class simply instantiate it.
	(no parameters needed)
	**/
	public static void main(String[] parameters)
		{
		EmailParametersInputWindow window =
			new EmailParametersInputWindow();
		window.setVisible(true);
		}
	}
