package org.datamanager.collector.tools;

import org.datamanager.kernel.*;

import java.net.*;
import java.io.*;
import java.util.*;


public class NewsConnection
	{
	
	protected static final int NNTP_PORT = 119;

	protected Socket connection;
	protected PrintStream output;
	protected BufferedReader input;

	protected String server;
	protected String currentGroup;
	protected String currentMessage;


	private NewsConnection()
		{
		}

	public static NewsConnection getConnection()
		{
		return new NewsConnection();
		}

	public boolean connect(String server)
		throws IOException, UnknownHostException
		{
		this.server = server;
		return connect();
		}

	private boolean connect()
		throws IOException, UnknownHostException
		{
		// Create the connection to the server.
		// This could fail with a UnknownHostException or
		// an IOException.
		connection = new Socket(server, NNTP_PORT);
		
		// Create a BufferedReader for getting input from the server.
		// This variable is global to the class.
		this.input = new BufferedReader(
			new InputStreamReader(connection.getInputStream()));
		
		// Create a PrintStream for output to the server.
		// This variable is global to the class.
		this.output = new PrintStream(connection.getOutputStream());

		// Get rid of all the greeting messages sent when you first
		// connect to a news server.
		// This should return a string starting with the responce
		// code 200.
		input.readLine();
		
		return true;
		}

	public void disconnect()
		throws IOException
		{
		output.print("quit\r\n");

		connection.close();
		
		output = null;
		input = null;
		connection = null;
		}

	private void reconnect()
		throws IOException, UnknownHostException
		{
		// Connect to the server.
		connect();

		// Get back to the right group.
		group(currentGroup);

		// Get back to the right message.
		article(currentMessage);
		}

	public boolean group(String group)
		throws IOException
		{
		output.print("group " + group + "\r\n");

		String responce;
		responce = input.readLine();

		String code = responce.substring(0, 3);
		//System.err.println("GROUP: responce == " + responce);
		if (code.equals("211"))
			{
			currentGroup = group;
			
			output.print("stat\r\n");
			String message = input.readLine();
			for (int count = 2; count > 0; count--)
				{
				message = message.substring(message.indexOf(" ") + 1, message.length());
				}

			currentMessage = message.substring(0, message.indexOf(" "));

			//System.err.println("GROUP: currentMessage == " + currentMessage);

			return true;
			}
		else if (code.equals("411"))
			{
			return false;
			}
		else
			{
			return false;
			}
		}

	public boolean stat(String message)
		throws IOException
		{
		output.print("stat " + message + "\r\n");
		
		String responce;
		responce = input.readLine();
		
		String code = responce.substring(0, 3);
		//System.err.println("STAT: responce == " + responce);
		if (code.equals("223"))
			{
			// Message selected.

			currentMessage = message;
			
			return true;
			}
		else if (code.equals("412"))
			{
			// No newsgroup selected.

			return false;
			}
		else if (code.equals("430"))
			{
			// No such article.
			
			return false;
			}
		else
			{
			return false;
			}
		}

	public boolean next()
		throws IOException
		{
		output.print("next\r\n");
		
		String responce;
		responce = input.readLine();
		
		String code = responce.substring(0, 3);
		//System.err.println("NEXT: responce == " + responce);
		if (code.equals("223"))
			{
			// Message selected.


			String article = responce;
			for (int count = 2; count > 0; count--)
				{
				article = article.substring(article.indexOf(" ") + 1, article.length());
				}

			currentMessage = article.substring(0, article.indexOf(" "));

			return true;
			}
		else if (code.equals("412"))
			{
			// No newsgroup selected.

			return false;
			}
		else if (code.equals("420"))
			{
			// No current article has been selected.
			
			return false;
			}
		else if (code.equals("421"))
			{
			// No next article in this group.
			
			return false;
			}
		else
			{
			return false;
			}
		}

	public String head()
		throws IOException
		{
		return head(currentMessage);
		}

	public String head(String message)
		throws IOException
		{
		output.print("head " + message + "\r\n");
		
		String responce;
		responce = input.readLine();
		
		String code = responce.substring(0, 3);
		//System.err.println("HEAD: responce == " + responce);
		if (code.equals("221"))
			{
			// Headers follow.

			// Junk the first line of the responce. It is
			// not part of the headers.
			responce = "";
			String line = input.readLine();
			while (!line.equals("."))
				{
				responce = responce + "\n" + line;
				line = input.readLine();
				}

			// If the headers are not empty.
			if (!responce.equals(""))
				{
				// Remove the first \n.
				responce = responce.substring(responce.indexOf("\n"), responce.length());
				}

			return responce;
			}
		else if (code.equals("412"))
			{
			// No newsgroup selected.

			return "HEAD: No newsgroup selected.";
			}
		else if (code.equals("420"))
			{
			// No current article has been selected.
			
			return "HEAD: No current article has been selected.";
			}
		else if (code.equals("430"))
			{
			// No such article found.
			
			return "HEAD: No such article found.";
			}
		else
			{
			return "HEAD: Unknown error.";
			}		
		}

	public String body()
		throws IOException
		{
		return body(currentMessage);
		}

	public String body(String message)
		throws IOException
		{
		output.print("body " + message + "\r\n");
		
		String responce;
		responce = input.readLine();
		
		String code = responce.substring(0, 3);
		//System.err.println("BODY: responce == " + responce);
		if (code.equals("222"))
			{
			// Body follows.

			// Junk the first line of the responce. It is
			// not part of the body.
			responce = "";
			String line = input.readLine();
			while (!line.equals("."))
				{
				responce = responce + "\n" + line;
				line = input.readLine();
				}

			// If the body is not empty.
			if (!responce.equals(""))
				{
				// Remove the first \n.
				responce = responce.substring(responce.indexOf("\n"), responce.length());
				}

			return responce;
			}
		else if (code.equals("412"))
			{
			// No newsgroup selected.

			return "BODY: No newsgroup selected.";
			}
		else if (code.equals("420"))
			{
			// No current article has been selected.
			
			return "BODY: No current article has been selected.";
			}
		else if (code.equals("423"))
			{
			// No such article found.
			
			return "BODY: No such article found.";
			}
		else
			{
			return "BODY: Unknown error.";
			}		
		}

	public String article()
		throws IOException
		{
		return article(currentMessage);
		}

	public String article(String message)
		throws IOException
		{
		output.print("article " + message + "\r\n");
		
		String responce;
		responce = input.readLine();
		
		String code = responce.substring(0, 3);
		//System.err.println("ARTICLE: responce == " + responce);
		if (code.equals("220"))
			{
			// Headers and body follows.

			// Junk the first line of the responce. It is
			// not part of the body.
			responce = "";
			String line = input.readLine();
			while (!line.equals("."))
				{
				// Part of NNTP.
				if ((line.length() > 1) &&
				    line.substring(0, 2).equals(".."))
					{
					// Cut off the first "."
					line = line.substring(1, line.length());
					}

				responce = responce + "\n" + line;
				line = input.readLine();
				}

			// If the body is not empty.
			if (!responce.equals(""))
				{
				// Remove the first \n.
				responce = responce.substring(responce.indexOf("\n"), responce.length());
				}

			return responce;
			}
		else if (code.equals("412"))
			{
			// No newsgroup selected.

			return "ARTICLE: No newsgroup selected.";
			}
		else if (code.equals("420"))
			{
			// No current article has been selected.
			
			return "ARTICLE: No current article has been selected.";
			}
		else if (code.equals("423"))
			{
			// No such article found.
			
			return "ARTICLE: No such article found.";
			}
		else
			{
			return "ARTICLE: Unknown error.";
			}
		}

	public String getCurrentGroup()
		{
		return currentGroup;
		}

	public String getCurrentMessage()
		{
		return currentMessage;
		}
	}