/**
 * BaseExistsConstraint.java
 *
 * Created 199911051504
 *
 * @author Benjamin Keil
 * @author Matthew Farrellee
 */

package org.datamanager.constraint;

import org.datamanager.constraint.EntityConstraint;
import org.datamanager.kernel.Entity;
import org.datamanager.tools.Debug;
import org.datamanager.exception.DataManagerException;
import org.datamanager.kernel.AbstractEntityConstraint;

public class BaseExistsConstraint extends AbstractEntityConstraint {
    
    private EntityConstraint baseConstraint;

    public BaseExistsConstraint(EntityConstraint baseConstraint)
    {
	this.baseConstraint = baseConstraint;
    }

    public boolean describes(Entity defendant)
    {
	try {
	    Entity[] bases = defendant.getBases(EntityConstraint.NONE);
	    
	    boolean doesMatch = false;
	    int index = 0;
	    
	    while (index < bases.length && doesMatch != true) {
		doesMatch = baseConstraint.accepts(bases[index++]);
	    }
	    
	    return doesMatch;
	}
	catch (DataManagerException exception) {
	    Debug.assert("defendant.getBases(EntityConstraint.NONE) threw: " +
			 exception);
	    
	    return false;
	}
    }
} // BaseExistsConstraint