/**
 * EntityConstraint.java
 * @author Benjamin Keil
 * @author Matthew Farrellee
 *
 * Created 199909282027
 */

package org.datamanager.constraint;

import org.datamanager.kernel.Entity;

import java.io.Serializable;

/**
 * Constraints define a set of entities.  For any given entity, a constraint's
 * accepts method should return true if that Entity is a member of its set, and
 * false if it doesn't.
 */
public abstract interface EntityConstraint extends Serializable
{
    /**
     * Matches all entities.
     */
    public static final EntityConstraint NONE = NoneConstraint.getInstance();

    /**
     * Reports whether a given entity fits the set of Entities defined by
     * this constraint.
     */
    public abstract boolean accepts(Entity defendant);
}
