package org.datamanager.engine.filter;

import java.util.*;
/**
 * This class creates the weight list of the weights of the corresponding
 * core-words from the content of the document.
 *
 * @author Chao
 * @author Aleksander Slominski
 */




public class WeightedWordList extends HashMap implements org.datamanager.kernel.EntityValue {
  
    /** @serial Variable to keep track of the number of the words */
    private int maxCount = 0;
    
    /** Constructor does not take any arguments.This method creates filter*/
    public WeightedWordList(){
    }

    /** This is the method that gets the weighted word. It takes in a word 
     * as it's argument and returns a weighted word.*/
    public WeightedWord getWeightedWord(String word) {
	return (WeightedWord)get(word);
    }

/** This is the method that increments the count of the words */
    public void incrementCount(String word){
	WeightedWord ww = getWeightedWord(word);
	if(ww != null) {
	    ww.increment();
	} else {
	    ww = new WeightedWord(word);
	    put(word, ww);
	}
	if(maxCount < ww.getCount()) {
	    maxCount = ww.getCount();
	}
    }

/** Method that returns the count of the words. */
    public int getMaxCount(){
	return maxCount;
    }

/** Method that actually does the weighting. */
    public void doWeighting() {
	Iterator i = keySet().iterator();
	while(i.hasNext()) {
	    WeightedWord ww = (WeightedWord) get(i.next());
	    //Debug.assert(ww != null)
	    ww.weight = (maxCount == 0) ? 0 : (double)ww.getCount() / maxCount;
	} 
    }

  public String toString() {
    StringBuffer buf = new StringBuffer();
    WeightedWord ww;
    for(Iterator i = keySet().iterator(); i.hasNext(); ) {
      Object key = i.next();
      ww = (WeightedWord) get(key);
      buf.append(ww.word+" ["+ww.weight+", "+ww.count+"]\n");
    }
    return buf.toString();
  }

}
