package org.datamanager.engine.filter;

/**
 * This class takes the a list of words or reads the words from the source and removes them.
 * This class implements the Filter interface. It plays the role of 
 * filtering words from the document that won't be needed . It's the 
 * the general class that will remove the stop words and the determiner.
 * words. It contains three constructors. The first constructor does 
 * not take any arguments. This constructor will be used in the case 
 * where there are no words to be removed. The second constructor, takes
 * in a string of words as the argument. This is used in the case where 
 * the user comes in with a list of words. The third constructor takes in 
 * a filename as it's argument.This is used in the case where the words 
 * have to be read from a file.
 *
 * The method 'process' in this class does the actual removal of words.
 *
 * @author Chao
 * @author Aleksander Slominski
 */

import java.util.*;
import java.io.*;

public class WordRemovingFilter implements Filter{
    
    /** 
     * @serial a hashtable will store all the words that need to be removed.
     */
    private Hashtable removableWords = new Hashtable();
    
    /** @serial delimiters for separating the string into tokens*/
    private final static String delimiters= ".,\";:?!\n\t\r~!@%^&*()-+={}[]<> ,       ";

    /** declare a static object variable to be used by the second constructor */
    private final static org.datamanager.passiveentityvalue.StringEntityValue NOT_NULL = new org.datamanager.passiveentityvalue.StringEntityValue("NOT_NULL");

    //////////////////////////////////////////////////////////////////

    /**
     * This constructor is called when there are no words to be removed from 
     * the document
     */

    public WordRemovingFilter(){
    }

    /**
     *This constructor is called when there is an incoming list
     * of words from the user
     */
    public WordRemovingFilter(String[] wordList) {
	for(int i = 0; i < wordList.length; ++i)
	    removableWords.put(wordList[i], NOT_NULL);
    }

    /** 
     *  This constructor is called when the words are read from the source file.
     *  Creates filter with list of words read from fileName.
     *  Each line contains the word.
     *
     * @throws FilterException
     */
    public WordRemovingFilter(String fileName) throws FilterException {
	//Debug.assert (fileName != null);
	String line = new String ();

	try {
	    BufferedReader bufferReader = new BufferedReader(new FileReader(fileName));  
	    while ( (line = bufferReader.readLine() ) != null ) {
		/** Hashtable is used to determine if a word is on list. */
		removableWords.put(line, NOT_NULL);
		System.out.println("putting line "+line);
	    }
	}
	catch (IOException exception) {   
	    //Debug.trace("engine", "Error reading the file");
	    throw new FilterException("Error reading the file "+fileName+" with list of the words");
	}
    }

    /////////////////////////////////////////////////////////////////////////
    /**
     * This is the method that actually does the removable of the words 
     */

    public Object process(Object content){
	//Debug.assert (content != null);
	if(content instanceof String == false)
	    throw new IllegalArgumentException("Expected string");
        StringTokenizer token = new  StringTokenizer((String)content, delimiters);  
        StringBuffer newContent = new StringBuffer ();

        while(token.hasMoreElements()) {
	    String word = token.nextToken();
	    if(removableWords.get(word) == null) {
		newContent.append(word).append(' ');
	    }
	}
        return newContent.toString();
    }
}
