package org.datamanager.engine.tools;

import java.io.*;
import java.util.*;
import java.text.DecimalFormat;
import Jama.*;
import org.datamanager.engine.cluster.*;


/** 
 * Latent Semantic Analysis gives the statistical 
 * co-occurrence picks up of the semantic information.
 * Implementation of basic algorithms for LSA originally 
 * referred to as LSI (Latent Semantic Indexing).
 *
 * @author Aleksander Slominski
 */ 

public class LSA implements org.datamanager.kernel.EntityValue {
    public static final double SIMILARITY_THRESHOLD = 0.95;
    /** @serial */
    private final static boolean PRINTING = false;
    /** @serial */
    private Matrix Q;
    /** @serial */
    private int maxDimension = 4; //100; 
    //private static DecimalFormat fmt = new DecimalFormat("0.0");
    //private static DecimalFormat fmt = new DecimalFormat("0.0000E00");
    private static DecimalFormat fmt = new DecimalFormat("0.00000000000000000E0");

    /**
     * Recompute SVD and prepare query matrix.
     * Best desription: http://www.cs.utk.edu/~berry/lsi++/
     */

    public void recomputeSVD(double[][] vals, int m, int n) {
	Assertion.check(m > 0);
	Assertion.check(n > 0);
	Assertion.check(m >= n);
	Assertion.check(vals.length == m);
	Assertion.check(vals[0].length == n);
	Matrix A = new Matrix(vals, m, n);
	SingularValueDecomposition svd = A.svd();
	int maxSize = Math.min(maxDimension - 1, svd.getU().getColumnDimension() - 1); 
	System.err.println("m="+m+" n="+n+" maxSize="+maxSize+" S size="+(svd.getS().getColumnDimension() - 1));
	Matrix U = svd.getU().getMatrix(0, svd.getU().getRowDimension() - 1, 0, maxSize);
	print("recomputeSVD U=",U);
	Matrix S = svd.getS().getMatrix(0, maxSize, 0, maxSize);
	print("recomputeSVD S=",S);
	Q = U.times(S.inverse());	    
	print("recomputeSVD Q=",Q);
    }

    public double[] query(double[] terms) {
	if(Q == null) { 
	    return terms;
	}
	Assertion.check(terms != null);
	Assertion.check(terms.length == Q.getRowDimension());
	Matrix m = new Matrix(terms, 1);
	print("query terms=",m);
	m = m.times(Q);
	print("query mQ=",m);
	double[] result = m.getColumnPackedCopy();
	print("query reult=",new Matrix(result, 1));
	return result;
    }

    public void setDimensions(int d) {
	maxDimension = Math.max(4, Math.min(100, d)); //LSA does not work well outside (4,100)
	//System.err.println("maxDimension ="+maxDimension);
    }

    private static void print(String msg, Matrix m) {
	if(PRINTING) {
	    System.out.println("\n"+msg);
	    m.print(fmt,18);
	}
    }
}
