/**
 * AttachLinkEvent.java
 */

package org.datamanager.event;

import org.datamanager.event.LinkEvent;
import org.datamanager.event.GenericEvent;
import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EventGenerator;

/**
 * This event is fired when <code>Entity.attach()</code>
 * is invoked.
 *
 * @author Matthew Farrellee
 */
public class AttachLinkEvent
   extends GenericEvent
   implements LinkEvent
    {
    /**
     * The <code>Entity</code> that was attached.
     */
    private Entity attachedEntity;


   /**
    * The public constructor used to create an
    * <code>AttachLinkEvent</code>.
    *
    * @param source The source of this event. Usually 'this.'
    * @param attachedEntity The <code>Entity</code> that was attached.
    */
   public AttachLinkEvent(EventGenerator source, Entity attachedEntity)
      {
      super(source);
      this.attachedEntity = attachedEntity;
      }


   /**
    * Report the <code>Entity</code> that was attached.
    *
    * @return Entity The <code>Entity</code> that was attached.
    */
   public Entity getAttachedEntity()
      {
      return attachedEntity;
      }



   /**
    * A toString() method to provide a meaningful <code>String</code>
    * representation of this event.
    *
    * @return String A meaningful <code>String</code> representation
    *                of this event.
    */
   public String toString()
      {
      return "AttachLinkEvent[[source: " + source + "]" +
             "[attachedEntity: " + attachedEntity + "]" +
             "[time: " + time + "]]";
      }
   }
