package org.datamanager.event;

import org.datamanager.event.LinkEvent;
import org.datamanager.event.GenericEvent;
import org.datamanager.kernel.EventGenerator;
import org.datamanager.kernel.Entity;

/**
 * This event is fired when <code>Entity.detach()</code>
 * is invoked.
 *
 * @author Matthew Farrellee
 */
public class DetachLinkEvent
   extends GenericEvent
   implements LinkEvent
   {
   /**
    * The <code>Entity</code> that was detached.
    */
   private Entity detachedEntity;


   /**
    * The public constructor used to create a
    * <code>DetachLinkEvent</code>.
    *
    * @param source The source of this event. Usually 'this.'
    * @param detachedEntity The <code>Entity</code> that was detached.
    */
   public DetachLinkEvent(EventGenerator source, Entity detachedEntity)
      {
      super(source);
      this.detachedEntity = detachedEntity;
      }


   /**
    * Report the <code>Entity</code> that was detached.
    *
    * @return Entity The <code>Entity</code> that was detached.
    */
   public Entity getDetachedEntity()
      {
      return detachedEntity;
      }


   /**
    * A toString() method to provide a meaningful <code>String</code>
    * representation of this event.
    *
    * @return String A meaningful <code>String</code> representation
    *            of this event.
    */
   public String toString()
      {
      return "DetachLinkEvent[[source: " + source + "]" +
            "[detachedEntity: " + detachedEntity + "]" +
            "[time: " + time + "]]";
      }
   }
