/**
 * GenericEvent.java
 */

package org.datamanager.event;

import org.datamanager.kernel.EventGenerator;
import org.datamanager.event.DataManagerEvent;

/**
 * This class is an implementation of DataManagerEvent.
 * Its main function is to implement the generic methods
 * required by a DataManagerEvent. This class can be
 * extended by any event to take care of method such
 * as getTime(), getSource(). This class is abstract
 * because it requires any subclass to implement the
 * toString() method required by DataManagerEvent.
 *
 * @author Matthew Farrellee
 */
public abstract class GenericEvent
   implements DataManagerEvent
   {
   protected long time;
   protected EventGenerator source;

   public GenericEvent(EventGenerator source)
      {
      time = System.currentTimeMillis();
      this.source = source;
      }

   /**
    * Report the object that generated this event.
    *
    * @return EventGenerator The source of this event.
    */
   public EventGenerator getSource()
      {
      return source;
      }
   
   /**
    * Report the time at which this event was created (in milliseconds).
    *
    * @return long The time of the event's creation
    *              (in milliseconds).
    */
   public long getTime()
      {
      return time;
      }

   public abstract String toString();
   }