package org.datamanager.event;

import org.datamanager.event.DataManagerEvent;
import org.datamanager.kernel.*;
import org.datamanager.constraint.*;

/**
 * This marker interface is the mother of all
 * events generated from within the kernel of
 * the <code>DataManager</code>.
 *
 * This is just a marker interface. It specifies
 * no unique methods of its own.
 * It does however extend <code>DataManagerEvent<code>
 * and therefore requires:
 * public EventGenerator getSource()
 * public long getTime()
 * public String toString()
 *
 * @author Matthew Farrellee
 */
public class InterfaceSearchEvent implements InterfaceEvent {
   
   private EventGenerator source;
   private long time;
   private EntityConstraint constraint;
   public InterfaceSearchEvent(EventGenerator source, EntityConstraint constraint) {
      this.source = source;
      this.constraint = constraint;
      time = System.currentTimeMillis();
      }
   public EventGenerator getSource() {
      return source;
      }
   public long getTime() {
      return time;
      }
   public String toString() {
      return "InterfaceSearchEvent[constraint,source,time]";
      }
   public EntityConstraint getConstraint() {
      return constraint;
      }
   }