package org.datamanager.event;

import org.datamanager.event.PoolEvent;
import org.datamanager.event.GenericEvent;
import org.datamanager.kernel.EventGenerator;
import org.datamanager.constraint.EntityConstraint;

/**
 * This event is fired when <code>Pool.search()</code>
 * is invoked.
 *
 * @author Matthew Farrellee
 */
public class SearchEvent
   extends GenericEvent
   implements PoolEvent
   {
   /**
    * The <code>EntityConstraint</code> that was used in the search.
    */
   private EntityConstraint constraint;


   /**
    * The public constructor used to create a <code>SearchEvent</code>.
    *
    * @param source The source of this event. Usually 'this.'
    * @param constraint The <code>EntityConstraint</code> that was used
    *               for the search.
    */
   public SearchEvent(EventGenerator source, EntityConstraint constraint)
      {
      super(source);
      this.constraint = constraint;
      }

   /**
    * Report the <code>EntityConstraint</code> that was used in the search.
    *
    * @return EntityConstraint The <code>EntityConstraint</code> used for the
    *               search.
    */
   public EntityConstraint getConstraint()
      {
      return constraint;
      }


   /**
    * A toString() method to provide a meaningful <code>String</code>
    * representation of this event.
    *
    * @return String A meaningful <code>String</code> representation
    *            of this event.
    */
   public String toString()
      {
      return "SearchEvent[[source: " + source + "]" +
         "[constraint: " + constraint + "]" +
         "[time: " + time + "]]";
      }
   }