package org.datamanager.event;

import org.datamanager.event.KernelEvent;
import org.datamanager.kernel.EventGenerator;
import org.datamanager.kernel.EventHandler;
import org.datamanager.constraint.EventConstraint;

/**
 * This event is fired when
 * <code>EventGenerator.unsubscribed()</code> is invoked.
 *
 * @author Matthew Farrellee
 */
public class UnsubscribeEvent
   extends GenericEvent
   implements KernelEvent
   {
   /**
    * The <code>EventConstraint</code> that was unsubscribed.
    */
   private EventConstraint constraint;

   /**
    * The <code>EventHandler</code> that was unsubscribed.
    */
   private EventHandler handler;



   /**
    * This public constructor used to create a
    * <code>UnsubscribeEvent</code> that does not contain
    * a <code>EventConstraint</code>.
    *
    * @param source The source of this event. Usually 'this.'
    * @param handler The <code>EventHandler</code> that was
    *                unsubscribed.
    */
   public UnsubscribeEvent(EventGenerator source,
                           EventHandler handler)
      {
      this(source, handler, null);
      }

   /**
    * This public constructor used to create a
    * <code>UnsubscribeEvent</code> that does contain
    * a <code>EventConstraint</code>.
    *
    * @param source The source of this event. Usually 'this.'
    * @param handler The <code>EventHandler</code> that was
    *                unsubscribed.
    * @param constraint The <code>EventConstraint</code> that was
    *                   unsubscribed.
    */
   public UnsubscribeEvent(EventGenerator source,
                        EventHandler handler,
                        EventConstraint constraint)
      {
      super(source);
      this.handler = handler;
      this.constraint = constraint;
      }

   /**
    * Report the <code>EventHandler</code> that was unsubscribed.
    *
    * @return EventHandler The <code>EventHandler</code> that was
    *                    unsubscribed.
    */
   public EventHandler getEventHandler()
      {
      return handler;
      }

   /**
    * Report the <code>EventConstraint</code> that was unsubscribed.
    *
    * @return EtityConstraint The <code>EventConstraint</code> that was
    *                    unsubscribed.
    */
   public EventConstraint getConstraint()
      {
      return constraint;
      }
   
   /**
    * A toString() method to provide a meaningful <code>String</code>
    * representation of this event.
    *
    * @return String A meaningful <code>String</code> representation
    *                of this event.
    */
   public String toString()
      {
      return "UnsubscribeEvent[[source: " + source + "]" +
         "[eventHandler: " + handler + "]" +
         "[eventconstraint: " + constraint + "]" +
         "[time: " + time + "]]";
      }
   }