/**
 * DataManagerThread.java
 */

package org.datamanager.kernel;


/**
 * This class is the parent of all threads that are run
 * within the kernel and can work on Entities. It has
 * a special switch for events. This allows the kernel
 * when it should fire events from Entities. For example,
 * if a Constraint is working on an Entity it should not
 * fire an event, so the switch is turned off, while
 * the Thread is executing within the Constraint, and
 * turned back on when it leaves the Constraint. This
 * is done from within the AbstractConstraint class.
 *
 * @author Matthew Farrellee
 */
class DataManagerThread extends Thread
   {
   // The switch for determining if an event should
   // be fired or not.
   private boolean generateEvent;


	private DataManagerWorker worker;

   /**
    * The package access constructor. Default for
    * the switch is on (true).
    */
   DataManagerThread()
      {
		super();
      generateEvents(true);
      }

	void reset(DataManagerWorker worker)
		{
		this.worker = worker;
		}

	public void run()
		{
		worker.process();
		}

   /**
    * A package access method for setting the event
    * generation switch. True is on and False is off.
    */
   void generateEvents(boolean generateEvent)
      {
      this.generateEvent = generateEvent;
      }

   /**
    * Test to see if this thread should cause an event.
    */
   boolean isEventGenerating()
      {
      return generateEvent;
      }


	DataManagerWorker getWorker()
		{
		return worker;
		}

	public String toString()
		{
		return worker.toString();
		}
   }
