/**
 * EntityManager.java
 *
 * Created 199909280824
 */ 

package org.datamanager.kernel;

import java.io.Serializable;
import java.io.FileInputStream;
import java.io.ObjectInputStream;
import java.io.File;
import java.io.OptionalDataException;
import java.io.IOException;

import org.datamanager.tools.Debug;

/**
 * The EntityManager is responsible for maintaining lookup tables between
 * the system IDs, the EntityProxies, and the actually entities they proxy
 * for.  Ideally, an EntityManager should also cache unused Entities to
 * disk and perform other such optomizations. 
 *
 * @author Benjamin Keil
 * @author Matthew Farrellee
 */

abstract class EntityManager
	{

	private static EntityManager instance;

	static
		{
		File file = new File("startup" + File.separator + "ObjectStore");
		if (file.exists())
			{
			try
				{
				FileInputStream fis = new FileInputStream(file);
				ObjectInputStream ois = new ObjectInputStream(fis);
				instance = (EntityManager) ois.readObject();
				Debug.assert("EntityManager.instance==" + instance);
				}
			catch (OptionalDataException exception)
				{
				Debug.assert("***loading system: " + exception);
				instance = new VerySimpleEntityManager();
				}
			catch (ClassNotFoundException exception)
				{
				Debug.assert("***loading system: " + exception);
				instance = new VerySimpleEntityManager();
				}
			catch (IOException exception)
				{
				Debug.assert("***loading system: " + exception);
				instance = new VerySimpleEntityManager();
				}
			}
		else
			{
			instance = new VerySimpleEntityManager();
			}
		}

	static EntityManager getInstance()
		{
		return instance;
		}

	abstract EntityProxy createEntity(String name);

	abstract EntityProxy findProxy(Identifier wanted);

	abstract VerySimpleEntity findEntity(Identifier wanted);

	abstract Identifier findIdentifier(EntityProxy wanted);

	abstract Identifier findIdentifier(VerySimpleEntity wanted);
	} // EntityManager


