package org.datamanager.kernel;

import org.datamanager.constraint.EventConstraint;
import org.datamanager.kernel.EventHandler;
import org.datamanager.kernel.DataManagerThread;
import org.datamanager.event.DataManagerEvent;
import org.datamanager.exception.DataManagerException;
import org.datamanager.tools.Debug;
import java.util.*;
import java.io.*;

/**
 * class EventGeneratorAssistant
 *
 * @author Matthew Farrellee
 */
class EventGeneratorAssistant implements Serializable
   {
   private Hashtable listeners;

   EventGeneratorAssistant()
      {
      listeners = new Hashtable(5);
      }


   synchronized void addEventHandler(EventHandler handler,
         EventConstraint constraint)
      {
      if (listeners.containsKey(handler))
         {
         ((Vector) listeners.get(handler)).add(constraint);
         }
      else
         {
         Vector constraints = new Vector(5, 5);
         constraints.add(constraint);
         listeners.put(handler, constraints);
         }
      }


   synchronized void removeEventHandler(EventHandler handler)
      {
      listeners.remove(handler);
      }

   synchronized void removeEventHandler(EventHandler handler,
         EventConstraint constraint)
      {
      if (listeners.containsKey(handler))
         {
         Vector constraints = (Vector) listeners.get(handler);

         constraints.remove(constraint);

         if (constraints.isEmpty())
            {
            removeEventHandler(handler);
            }
         }
      }


   // Should EventHandlers get an event more than once
   // if they are registered with more than one Constraint
   // that accepts the event?
   synchronized void fireEvent(DataManagerEvent event)
      {
      try
         {
         DataManagerThread thread =
               (DataManagerThread) Thread.currentThread();

         if (thread.isEventGenerating())
            {
            Enumeration handlers = listeners.keys();
            ThreadManager manager =
                  ThreadManager.getInstance();

            EventHandler handler;
            Enumeration constraints;
            while (handlers.hasMoreElements())
               {
               handler = (EventHandler) handlers.nextElement();

               constraints =
                     ((Vector) listeners.get(handler)).elements();

               while (constraints.hasMoreElements())
                  {
                  if (((EventConstraint) constraints.nextElement()).
                        accepts(event))
                     {
                     manager.register(handler, event);
                     }
                  }
               }
            }
         }
      catch (ClassCastException exception)
         {
         // This should really never happen. If it has
         // then it means that someone is running a thread
         // of their own that is not valid.
         // The thread should really be killed at this point,
         // but maybe it would be better just to report the
         // rogue thread to the ThreadManager.

         Debug.assert("illegal thread running in the system: " +
               Thread.currentThread());
         }
      }
   }
