package org.datamanager.kernel;

import java.awt.*;
import javax.swing.*;
import java.util.*;
import java.awt.event.*;
import javax.swing.event.*;
import javax.swing.border.*;

import org.datamanager.tools.Information;

class KernelWindow extends JFrame
	{
	private GridBagLayout gridBagLayout = new GridBagLayout();
	private GridBagConstraints constraints = new GridBagConstraints();

	private JButton closeButton = new JButton("Shutdown");
	private JButton startSimpletonButton =
		new JButton("Start Simpletons");
	private JButton startInterfaceButton =
		new JButton("Start UserInterfaces");
	private Vector interfaceObjects = new Vector();
	private Vector simpletonObjects = new Vector();
	private DefaultListModel interfaceNames = new DefaultListModel();
	private DefaultListModel simpletonNames = new DefaultListModel();
	private JList interfaceList = new JList(interfaceNames);
	private JList simpletonList = new JList(simpletonNames);
	private JScrollPane interfacePane = new JScrollPane(interfaceList);
	private JScrollPane simpletonPane = new JScrollPane(simpletonList);



	KernelWindow()
		{
		makeGui(getContentPane());

		setupComponents();
		}


	private void makeGui(Container container)
		{
		container.setLayout(gridBagLayout);

		constraints.weightx = 1;
		constraints.weighty = 1;

		constraints.gridy = 1;
		constraints.gridx = 2;
		constraints.gridwidth = 1;
		container.add(startInterfaceButton, constraints);

		constraints.gridx = 3;
		constraints.gridwidth = GridBagConstraints.REMAINDER;
		container.add(startSimpletonButton, constraints);

		constraints.gridy = 3;
		constraints.gridx = 2;
		constraints.gridwidth = 1;
		constraints.fill = GridBagConstraints.BOTH;
		container.add(interfacePane, constraints);

		constraints.gridx = 4;
		constraints.gridwidth = 1;//GridBagConstraints.REMAINDER;
		container.add(simpletonPane, constraints);

		constraints.fill = GridBagConstraints.NONE;
		constraints.gridy = 6;
		constraints.gridx = 2;
		constraints.gridwidth = GridBagConstraints.REMAINDER;
		container.add(closeButton, constraints);
		}


	private void setupComponents()
		{

		interfaceList.setCellRenderer(new ToolTipCellRenderer());
		simpletonList.setCellRenderer(new ToolTipCellRenderer());

		//ToolTipManager.sharedInstance().registerComponent(interfaceList);
		//ToolTipManager.sharedInstance().registerComponent(simpletonList);

		addWindowListener(new WindowAdapter()
			{
			public void windowClosing(WindowEvent event)
				{
				System.exit(0);
				}
			});

		closeButton.addActionListener(new ActionListener()
			{
			public void actionPerformed(ActionEvent event)
				{
				System.exit(0);
				}
			});

		startSimpletonButton.addActionListener(new ActionListener()
			{
			public void actionPerformed(ActionEvent event)
				{
				int[] items = simpletonList.getSelectedIndices();
				for (int i = 0; i < items.length; i++)
					{
					System.err.println("started: " +
						simpletonObjects.elementAt(items[i]));
					ThreadManager.getInstance().register(
						(Simpleton) simpletonObjects.elementAt(items[i]));
					}
				}
			});

		startInterfaceButton.addActionListener(new ActionListener()
			{
			public void actionPerformed(ActionEvent event)
				{
				int[] items = interfaceList.getSelectedIndices();
				for (int i = 0; i < items.length; i++)
					{
					System.err.println("started: " +
						interfaceObjects.elementAt(items[i]));
					ThreadManager.getInstance().register(
						(Initializable) interfaceObjects.elementAt(items[i]));
					}
				}
			});

		interfaceList.addMouseListener(new MouseAdapter()
			{
			public void mouseClicked(MouseEvent event)
				{
				if (event.getClickCount() == 2)
					{
					int[] items = interfaceList.getSelectedIndices();
					for (int i = 0; i < items.length; i++)
						{
						System.err.println("started: " +
							interfaceObjects.elementAt(items[i]));
						ThreadManager.getInstance().register(
							(Initializable) interfaceObjects.elementAt(items[i]));
						}
					}
				}
			});

		simpletonList.addMouseListener(new MouseAdapter()
			{
			public void mouseClicked(MouseEvent event)
				{
				if (event.getClickCount() == 2)
					{
					int[] items = simpletonList.getSelectedIndices();
					for (int i = 0; i < items.length; i++)
						{
						System.err.println("started: " +
							simpletonObjects.elementAt(items[i]));
						ThreadManager.getInstance().register(
							(Simpleton) simpletonObjects.elementAt(items[i]));
						}
					}
				}
			});
		}


	void addInterface(Initializable userInterface)
		{
		interfaceObjects.addElement(userInterface);
		interfaceNames.addElement(userInterface.getInformation());
		}


	void addSimpleton(Simpleton simpleton)
		{
		simpletonObjects.addElement(simpleton);
		simpletonNames.addElement(simpleton.getInformation());
		}



	class ToolTipCellRenderer extends JLabel implements ListCellRenderer
		{
		ToolTipCellRenderer()
			{
			setOpaque(true);
			}

		public Component getListCellRendererComponent(
				JList list,
				Object value,            // value to display
				int index,               // cell index
				boolean isSelected,      // is the cell selected
				boolean cellHasFocus)    // the list and the cell have the focus
			{
			Information info = (Information) value;

			String text = info.getName();
			String toolTip = info.getShortDescription();
			setText(text);
			setToolTipText(toolTip);
			if (isSelected)
				{
				setBackground(list.getSelectionBackground());
				setForeground(list.getSelectionForeground());
				}
			else
				{
				setBackground(list.getBackground());
				setForeground(list.getForeground());
				}

			setEnabled(list.isEnabled());
			setFont(list.getFont());
			return this;
			}
		}
	}
