package org.datamanager.kernel;

import java.util.*;
import java.io.*;

import org.datamanager.kernel.DataManager;
import org.datamanager.kernel.DataManagerWorker;

import org.datamanager.tools.Debug;


abstract class LoaderProcess implements DataManagerWorker
	{
	private File directory;

	LoaderProcess(File directory)
		{
		this.directory = directory;
		}


	public void process()
		{
		// Get all the files from the directory that satisfy
		// the FilenameFilter.
		// The FilenameFilter only accepts files that exist,
		// are files, are readable, and are class files.
		String[] files = directory.list(new FilenameFilter()
			{
			public boolean accept(File dir, String name)
				{
				File file = new File(dir, name);
				
				return file.exists() && file.isFile() &&
							file.canRead() && isClass(name);
				}
			
			boolean isClass(String name)
				{
				return ((name.length() - name.lastIndexOf(".class")) ==
							".class".length());
				}
			});


		Class currentClass;
		Object loadedObject;
		for (int i = 0; i < files.length; i++)
			{
			try
				{
				currentClass =
					Class.forName(removeSuffix(files[i], ".class"));
				if (!currentClass.isInterface())
					{
					loadedObject = currentClass.newInstance();
					load(loadedObject);
					}
				}
			catch (ClassNotFoundException noClassFile)
				{
				// The file is not a class file.
				Debug.assert("Invalid class file: " + files[i]);
				}
			catch (IllegalAccessException noAccess)
				{
				// This should hopefully never happen.
				Debug.assert("Cannot access: " + files[i]);
					noAccess.printStackTrace();
				}
			catch (InstantiationException createError)
				{
				// For some reason an newInstance did not work. It is
				// possible that there is not a zero argument
				// constructor in the Class.
				Debug.assert( "Cannot create an instance of '" +
					files[i] + "'");
				}
			catch (ClassCastException wrongObjectType)
				{
				// The loadedObject was not of the right type.
				// Ignoring the class...
				Debug.assert(files[i] + " is of wrong type: " +
					wrongObjectType);
				}
			}
		}

	private String removeSuffix(String name, String suffix)
		{
		return name.substring(0, name.lastIndexOf(suffix));
		}


	protected abstract void load(Object object);
	}

