/**
 * Pool.java
 */

package org.datamanager.kernel;

import org.datamanager.kernel.EventGeneratorAssistant;

import org.datamanager.kernel.Entity;
import org.datamanager.constraint.EntityConstraint;
import org.datamanager.constraint.EventConstraint;
import org.datamanager.exception.DataManagerException;
import org.datamanager.kernel.EventGenerator;
import org.datamanager.kernel.EventHandler;

import org.datamanager.event.*;

import org.datamanager.tools.Debug;

import java.util.*;
import java.io.*;

/**
 * @author Matthew Farrellee
 */
public class Pool implements EventGenerator, Serializable
	{

	private static Pool instance;

	static
		{
		File file = new File("startup" + File.separator + "DefaultPool");
		if (file.exists())
			{
			try
				{
				FileInputStream fis = new FileInputStream(file);
				ObjectInputStream ois = new ObjectInputStream(fis);
				instance = (Pool) ois.readObject();
				instance.assistant = new EventGeneratorAssistant();
				Debug.assert("Pool.instance==" + instance);
				}
			catch (OptionalDataException exception)
				{
				Debug.assert("***loading DefaultPool: " + exception);
				instance = new Pool();
				}
			catch (ClassNotFoundException exception)
				{
				Debug.assert("***loading DefaultPool: " + exception);
				instance = new Pool();
				}
			catch (IOException exception)
				{
				Debug.assert("***loading DefaultPool: " + exception);
				instance = new Pool();
				}
			}
		else
			{
			instance = new Pool();
			}
		}



	private transient EventGeneratorAssistant assistant =
			new EventGeneratorAssistant();

	private Vector pool = new Vector();

	private Pool()
		{
		}

	public static Pool getDefaultPool()
		throws DataManagerException
		{
		return instance;
		}


	protected void fireEvent(DataManagerEvent event)
		{
		if (assistant == null)
			{
			loadNewAssistant();
			}

		assistant.fireEvent(event);
		}


	protected void loadNewAssistant()
		{
		assistant = new EventGeneratorAssistant();
		}


	public synchronized Entity[] search(EntityConstraint constraint)
	throws DataManagerException
		{

		fireEvent(new SearchEvent((EventGenerator) this, constraint));

		Vector acceptedEntities = new Vector();
		Iterator entities = pool.iterator();

		Entity entity;
		while (entities.hasNext())
			{
			entity = EntityManager.getInstance().findProxy((Identifier) entities.next());
			if (constraint.accepts(entity))
				{
				acceptedEntities.add(entity);
				}
			}

		Entity[] returnvalue = new Entity[acceptedEntities.size()];
		for (int index = 0; index < acceptedEntities.size(); index++)
			{
			returnvalue[index] = (Entity) acceptedEntities.elementAt(index);
			}

		return returnvalue;
		}

	public synchronized void add(Entity entity)
		throws DataManagerException
		{
		pool.add(EntityManager.getInstance().findIdentifier((EntityProxy) entity));
		fireEvent(new AddEntityEvent((EventGenerator) this, entity));
		}

	public synchronized void add(DataManagerEvent event)
		throws DataManagerException
		{
		fireEvent(event);
		}

	public synchronized void remove(Entity entity)
		throws DataManagerException
		{
		}


	/**
	  * Methods for EventGenerator.
	  */
	public synchronized void subscribe(EventHandler handler,
			EventConstraint constraint)
		throws DataManagerException
		{
		if (assistant == null)
			{
			loadNewAssistant();
			}

		assistant.addEventHandler(handler, constraint);
		fireEvent(new SubscribeEvent((EventGenerator) this, handler, constraint));
		}

	public synchronized void unsubscribe(EventHandler handler)
		throws DataManagerException
		{
		if (assistant == null)
			{
			loadNewAssistant();
			}

		assistant.removeEventHandler(handler);
		fireEvent(new UnsubscribeEvent((EventGenerator) this, handler));
		}



	public void finalize() throws Throwable
		{
		try
			{
			File file = new File("startup" + File.separator + "DefaultPool");
			FileOutputStream fos = new FileOutputStream(file);
			ObjectOutputStream oos = new ObjectOutputStream(fos);

			oos.writeObject(this);
			}
		catch (Exception e)
			{
			e.printStackTrace();
			}
		finally { super.finalize();
			}
		}
	}
