/**
 * VerySimpleEntityManager.java
 *
 * Created 199909280824
 */

/**
 * @author Benjamin Keil
 * @author Matthew Farrellee
 */
package org.datamanager.kernel;

import java.util.Hashtable;

import org.datamanager.kernel.Entity;

import org.datamanager.tools.Debug;

import java.io.*;


class VerySimpleEntityManager extends EntityManager implements Serializable
	{

	protected Hashtable proxyToIdentifier;
	protected Hashtable entityToIdentifier;
	protected Hashtable identifierToEntity;
	protected Hashtable identifierToProxy;


	protected IdentifierManager identifierManager =
			IdentifierManager.getInstance();


	VerySimpleEntityManager()
		{
		proxyToIdentifier = new Hashtable();
		entityToIdentifier = new Hashtable();
		identifierToEntity = new Hashtable();
		identifierToProxy = new Hashtable();
		}


	synchronized EntityProxy createEntity(String name)
		{
		VerySimpleEntity entity = new VerySimpleEntity(name);
		Identifier identifier = identifierManager.getNextIdentifier();
		EntityProxy entityProxy = new EntityProxy(identifier);

		proxyToIdentifier.put(entityProxy, identifier);
		identifierToEntity.put(identifier, entity);
		identifierToProxy.put(identifier, entityProxy);

		return entityProxy;
		}

	Identifier findIdentifier(EntityProxy wanted)
		{
		Debug.assert(wanted != null, "Trying to find Identifier for a null EntityProxy!");

		return (Identifier) proxyToIdentifier.get(wanted);
		}

	Identifier findIdentifier(VerySimpleEntity wanted)
		{
		Debug.assert(wanted != null, "Trying to find Identifier for a null VerySimpleEntity!");

		return (Identifier) entityToIdentifier.get(wanted);
		}

	EntityProxy findProxy(Identifier wanted)
		{
		Debug.assert(wanted != null, "Trying to find EntityProxy for a null Identifier!");

		return (EntityProxy) identifierToProxy.get(wanted);
		}
	  
	VerySimpleEntity findEntity(Identifier wanted)
		{
		Debug.assert(wanted != null, "Trying to find VerySimpleEntity for a null Identifier!");

		return (VerySimpleEntity) identifierToEntity.get(wanted);
		}

	public void finalize() throws Throwable
		{
		try
			{
			File file = new File("startup" + File.separator + "ObjectStore");
			FileOutputStream fos = new FileOutputStream(file);
			ObjectOutputStream oos = new ObjectOutputStream(fos);

			oos.writeObject(this);
			}
		catch (Exception e)
			{
			e.printStackTrace();
			}
		finally
			{ 
			super.finalize();
			} 
		}
	} // VerySimpleEntityManager