/**
 * EventEntityValue.java
 *
 * Created: Mon Oct 11 15:21:03 1999
 *
 * @author Benjamin Frederick Keil
 */

package org.datamanager.passiveentityvalue;

import org.datamanager.event.DataManagerEvent;

public class EventEntityValue implements HierarchicalEntityValue
    {

    DataManagerEvent value;

    public EventEntityValue(DataManagerEvent value)
        {
        this.value = value;
        }

    protected EventEntityValue()
        {
        }

    ///////////////////////////////////////////////////////////////////////////
    //                                                                       //
    //                           Ancestor Checks                             //
    //                                                                       //
    ///////////////////////////////////////////////////////////////////////////

    public boolean isParentOf(EventEntityValue val)
        {
        return this.isParentOf(val.value.getClass());
        }

    public boolean isParentOf(DataManagerEvent val)
        {
        return this.isParentOf(val.getClass());
        }

    public boolean isParentOf(Class val)
        {
        return getClass().isAssignableFrom(val);
        }

    public boolean isParentOf(HierarchicalEntityValue val)
        {
        if (val instanceof EventEntityValue)
            return this.isParentOf((EventEntityValue) val);
        else
            return false;
        }

    public boolean isParentOf(Object val)
        {
        if (val instanceof EventEntityValue)
            return this.isParentOf((EventEntityValue) val);
        else if (val instanceof Class)
            return this.isParentOf((Class) val);
        else if (val instanceof DataManagerEvent)
            return this.isParentOf((DataManagerEvent) val);
        else
            return false;
        }

    ///////////////////////////////////////////////////////////////////////////
    //                                                                       //
    //                          Descendant Checks                            //
    //                                                                       //
    ///////////////////////////////////////////////////////////////////////////

    public boolean isChildOf(EventEntityValue val)
        {
        return isChildOf(val.value.getClass());
        }

    public boolean isChildOf(DataManagerEvent val)
        {
        return isChildOf(val.getClass());
        }

    public boolean isChildOf(Class val)
        {
        return getClass().isInstance(val);
        }

    public boolean isChildOf(HierarchicalEntityValue val)
        {
        if (val instanceof EventEntityValue)
            return this.isChildOf((EventEntityValue) val);
        else
            return false;
        }

    public boolean isChildOf(Object val)
        {
        if (val instanceof EventEntityValue)
            return this.isChildOf((EventEntityValue) val);
        else if (val instanceof Class)
            return this.isChildOf((Class) val);
        else if (val instanceof DataManagerEvent)
            return this.isChildOf((DataManagerEvent) val);
        else
            return false;
        }
    } // EventEntityValue

