package org.datamanager.userinterface.cerulean.controller.tree;

import org.datamanager.userinterface.cerulean.view.tree.EntityTree;
import org.datamanager.userinterface.cerulean.model.tree.InterfaceNode;
import javax.swing.tree.TreePath;
import javax.swing.JTree;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

/**
 *This class is responsible for handling the users mouse clicks for the 
 *EntityTree of Cerulean.  It finds a path for the node that the users clicked
 *on, then tells that node to display itself (a method of InterfaceNode's).  
 *
 *@author Bryan Dawson (bdawson@indiana.edu)
 *@author Gordon Murphy (gpmurphy@indiana.edu)
 *
 *@see org.datamanager.userinterface.cerulean.view.tree.EntityTree
 *@see org.datamanager.userinterface.cerulean.model.tree.InterfaceNode
 *@see javax.swing.tree.TreePath
 *@see javax.swing.JTree
 */
//  Mehtods:
//  ~~~~~~~~
//  public ClickHandler(JTree)
//          Creates the Handler, the JTree is the tree for it is watching 
//  	mouse events for.
//  public void mouseClicked(MouseEvent)
//          This method gets the location that the user clicked at and askes
//          the JTree for the path that goes that to node.  If the user
//          double-clicked then the node that they clicked on is asked 
//          to display itself. If is the popup triger, the popup is displayed.
//          If it is neither of these then it sets the InterfaceEntity selected
//  public void mousePressed(MouseEvent)
//  public void mouseReleased(MouseEvent)
//          These methods have the popup code placed here also, to 
//  	    handle all platforms.
//////////////////////////////////////////////////////////////////////


public class ClickHandler extends MouseAdapter
   {
   /**
    *The tree that we will watching for mouse clicks in
    */
   private JTree tree;
   
   ////////////////////////////////////////////////////////////
   /* This creates the handler and gets the tree
   */
   public ClickHandler(JTree tree)
      {
      this.tree = tree;
      }

   /////////////////////////////////////////////////////////////
   /**
    *This gets the path for the location at which the user clicked.
    * This allows us to get the node for which the clicked on, and 
    * Tell it to display itself.If is the popup triger, the popup is displayed.
    * If it is neither of these then it sets the InterfaceEntity selected.
    *@param event Fired when the mouse is clicked.
    */
   public void mouseClicked(MouseEvent event)
      {
      int selRow = tree.getRowForLocation(event.getX(),event.getY());
      TreePath path = tree.getPathForLocation(event.getX(), event.getY());
         if(selRow != -1)
	     {
	     InterfaceNode node = (InterfaceNode)path.getLastPathComponent();
	     if(event.isPopupTrigger())
	     	node.handlePopup(tree, event.getX(), event.getY());
	     else if(event.getClickCount() == 2)
	        node.display();
           else
              {
              node.select();
              }
	     }
      }

   /////////////////////////////////////////////////////////////////     
   /**
    *The popup codes is here also, so that all platforms are supported.
    *@param event Fired when the user presses a mouse button.
    */
   public void mousePressed(MouseEvent event)
      {
      int selRow = tree.getRowForLocation(event.getX(),event.getY());
      TreePath path = tree.getPathForLocation(event.getX(), event.getY());
         if(selRow != -1)
	     {
	     InterfaceNode node = (InterfaceNode)path.getLastPathComponent();
	     if(event.isPopupTrigger())
	     	node.handlePopup(tree, event.getX(), event.getY());
    	     }
      }    	     	     	     
   /////////////////////////////////////////////////////////////////     
   /**
    *The popup codes is here also, so that all platforms are supported.
    *@param event Fired when the user releases a mouse button.
    */  
   public void mouseReleased(MouseEvent event)
      {
      int selRow = tree.getRowForLocation(event.getX(),event.getY());
      TreePath path = tree.getPathForLocation(event.getX(), event.getY());
         if(selRow != -1)
	     {
	     InterfaceNode node = (InterfaceNode)path.getLastPathComponent();
	     if(event.isPopupTrigger())
	     	node.handlePopup(tree, event.getX(), event.getY());
    	     }
      }          
   
   }//end of class



