/*
class org.datamanager.userinterface.cerulean.model.Abyss
KnownSpace: Cerulean

Authors:
~~~~~~~~
Gordon Murphy, gpmurphy@indiana.edu
Bryan Dawson, bdawson@indiana.edu
*/

package org.datamanager.userinterface.cerulean.model;

import org.datamanager.userinterface.cerulean.view.component.*;
import org.datamanager.userinterface.cerulean.view.component.BufferComponent;
import org.datamanager.userinterface.cerulean.view.component.AbyssComponent;
import org.datamanager.userinterface.cerulean.view.component.StageComponent;
import java.awt.Shape;
import java.io.*;
/**
 *
 * The circle manager is in charge of keeping track of the stage, buffer, and
 * abyss icons.  Classes may get an instance of this class using the static 
 * getInstance() method.  Once an instance is had, a reference to the stage,
 * buffer or abyss can be gotten.
 * 
 * @see Abyss
 * @see Buffer
 * @see InterfaceEntityManager
 * @see StageComponent
 * @see Shape
 *
 * @version 1.0
 * @author Gordon Murphy, gpmurphy@indiana.edu
 * @author Bryan Dawson, bdawson@indiana.edu 
 */

public class CircleManager implements Serializable {
	private static CircleManager defaultCircleManager;
	private Shape currentShape;
	private StageComponent currentStage;
	private AbyssComponent currentAbyss;
	private BufferComponent currentBuffer;
	protected CircleManager() {
		}
////////////////////////////////////////////////////////////////////////////////

	public static CircleManager getInstance() {
		if (defaultCircleManager == null) {
			defaultCircleManager = new CircleManager();
			}
		return defaultCircleManager;
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Set the circle's buffer to the specified buffer.
 * @param buffer the buffer to be added
 */
	public void setBuffer(BufferComponent buffer) {
		currentBuffer = buffer;
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Retrieve a reference to the current buffer.
 * @return The current buffer
 */
	public BufferComponent getBuffer() {
		return currentBuffer;
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Set the circle's stage to the specified stage.
 * @param stage the stage to be added
 */
	public void setStage(StageComponent stage) {
		currentStage = stage;
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Retrieve a reference to the current stage.
 * @return The current stage
 */
	public StageComponent getStage() {
		return currentStage;
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Set the circle's abyss to the specified abyss.
 * @param abyss the abyss to be added
 */
	public void setAbyss(AbyssComponent abyss) {
		currentAbyss = abyss;
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Retrieve a reference to the current abyss.
 * @return The current abyss
 */
	public AbyssComponent getAbyss() {
		return currentAbyss;
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Get the shape of the stage, buffer and abyss.
 * @return the current shape of the stage, buffer and abyss
 */
	public Shape getCurrentShape() {
		return currentShape;
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Set the shape of the stage, buffer and abyss.
 * @param newShape the new shape that the stage, buffer and abyss will have
 */
	public void setCurrentShape(Shape newShape) {
		currentShape = newShape;
		}
	}