/*
class org.datamanager.userinterface.cerulean.model.InterfaceEntityManager
KnownSpace: Cerulean

Authors:
~~~~~~~~
Gordon Murphy, gpmurphy@indiana.edu
Bryan Dawson, bdawson@indiana.edu
*/

////////////////////////////////////////////////////////////////////////////////

package org.datamanager.userinterface.cerulean.model.colorchooser;

import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.userinterface.cerulean.model.event.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;
import org.datamanager.userinterface.cerulean.model.data.storage.*;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.colorchooser.*;
import java.awt.geom.*;
import java.beans.*;

////////////////////////////////////////////////////////////////////////////////
/**
 * Creates a new color chooser window that allows a color to be chosen.
 * This sets the personalizeable's color to the currently displayed color
 * but if the user chooses to cancel, it reverts back to its original color.
 */
public class ColorChooser extends JWindow implements ActionListener {
	private JButton ok, cancel;
	private JColorChooser chooser;
	private Personalizable entity;
	private Paint initialPaint;
////////////////////////////////////////////////////////////////////////////////
/**
 * Creates a new ColorChooser for the specified personalizeable.
 */
	public ColorChooser(Personalizable entity) {
		super();
		this.entity = entity;
		initialPaint = entity.getPaint();
		chooser = new JColorChooser();
		getContentPane().setLayout(new BorderLayout());
		getContentPane().add(chooser, BorderLayout.CENTER);
		JPanel buttonPanel = new JPanel();
		ok = new JButton("ok");
		ok.addActionListener(this);
		cancel = new JButton("cancel");
		cancel.addActionListener(this);
		buttonPanel.add(ok);
		buttonPanel.add(cancel);
		getContentPane().add(buttonPanel,BorderLayout.SOUTH);
		getRootPane().setBorder(BorderFactory.createRaisedBevelBorder());
		}

	public void actionPerformed(ActionEvent e) {
		if (e.getSource()==ok) {
			hide();
			}
		if (e.getSource()==cancel) {
			entity.setPaint(initialPaint);
			hide();
			}
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Retrieve the currently selected color.
 * @return the currently selected color
 */
	public Color getColor() {
		return chooser.getColor();
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Add a change listener to this object.  Change events will be fired when a
 * color is chosen, or selected.
 */
	public void addChangeListener(ChangeListener listener) {
		chooser.getSelectionModel().addChangeListener(listener);
		}
	}