package org.datamanager.userinterface.cerulean.model.event;

import org.datamanager.userinterface.cerulean.model.InterfaceCluster;
import org.datamanager.userinterface.cerulean.model.data.storage.InterfaceEntityList;

////////////////////////////////////////////////////////////////////////////////
/**
 * An event encapsulating changes made to a cluster involving its contents.
 * A ClusterContentEvent is fired in three situations:
 *        <ul>
 *        <li>an entity, or entities, has been added to the cluster</li>
 *        <li>an entity, or entities, has been removed from the cluster</li>
 *        <li>an entity, or entities, has been moved from one cluster to
 *            the current cluster</li>
 *        </ul>
 * 
 * These events are passed to ClusterListeners that have registered to
 *  receive them.
 *
 * @see ClusterListener
 * @see ClusterEvent
 * @see InterfaceClusterManager
 *
 * @author Gordon Murphy
 */
public class ClusterContentEvent extends ClusterEvent {
	protected InterfaceEntityList entities;
////////////////////////////////////////////////////////////////////////////////
/**
 * Creates a new ClusterContentEvent.
 * @param source the originator of the event.
 * @param cluster the cluster that fired the event
 * @param entities the entities that modified the cluster
 */
	public ClusterContentEvent(Object source, InterfaceCluster cluster, InterfaceEntityList entities) {
		super(source, cluster);
		this.entities = entities;
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Retrieves all the entities that modified the cluster.
 * @return the entities that modified the cluster.
 */
	public InterfaceEntityList getEntities() {
		return entities;
		}
	}