package org.datamanager.userinterface.cerulean.model.event;

import org.datamanager.userinterface.cerulean.model.event.EntityEvent;
import org.datamanager.userinterface.cerulean.model.InterfaceEntity;

////////////////////////////////////////////////////////////////////////////////
/**
 * An event that is fired when an entity is attached to another entity.  
 *
 * @see ClusterListener
 * @see ClusterEvent
 *
 * @author Gordon Murphy
 */
public class EntityBoundEvent extends EntityEvent {
	private InterfaceEntity baseEntity;
	private InterfaceEntity boundEntity;
/**
 * Create a new event from the given entities.
 * @param source the originator of the event
 * @param baseEntity the base entity
 * @param boundEntity the attached entity
 */
	public EntityBoundEvent(Object source, InterfaceEntity baseEntity, InterfaceEntity boundEntity) {
		super(source, baseEntity);
		this.baseEntity = baseEntity;
		this.boundEntity = boundEntity;
		}
/**
 * Retrieve the base entity to which the entity will be attached.
 * @return the base entity
 */
	public InterfaceEntity getBaseEntity() {
		return baseEntity;
		}
/**
 * Retrieve the attached entity
 * @return the attached entity
 */
	public InterfaceEntity getBoundEntity() {
		return boundEntity;
		}
	}