package org.datamanager.userinterface.cerulean.model.event;

import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.userinterface.cerulean.model.event.*;
import org.datamanager.userinterface.cerulean.model.event.stage.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;
import org.datamanager.userinterface.cerulean.model.data.storage.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import java.awt.geom.*;
/**
 * The StageEventManager manages the events fired by the Stage.
 * It is in charge of holding StageListeners and firing the events.
 */

public class StageEventManager {
	private EventListenerList stageListenerList;

/**
 * Create a new StageEventManager with an empty listener list.
 */
	public StageEventManager() {
		stageListenerList = new EventListenerList();
		}
/**
 * Adds a stage listener to the list of interested classes.
 * @param listener the listener to add.
 */
	public void addStageListener(StageListener listener) {
		stageListenerList.add(listener.getClass(), listener);
		}
/**
 * Remove a stage listener from the list of interested classes.
 * @param listener the listener to remove.
 */
	public void removeStageListener(StageListener listener) {
		stageListenerList.remove(listener.getClass(), listener);
		}
/**
 * Fires an entityDisplayed event to all registered listeners.
 * @param source the originator of the event
 * @param entities the entities to be displayed.
 */
	public void fireEntitiesDisplayed(Object source, InterfaceEntityList entities) {
		Object[] listeners = stageListenerList.getListenerList();
		StageEvent stageEvent = new StageEvent(source, entities);
		for(int i = listeners.length - 2; i>=0; i-=2) {
			((StageListener)listeners[i+1]).entitiesDisplayed(stageEvent);
			}
		}
/**
 * Fires an entityUndisplayed event to all registered listeners.
 * @param source the originator of the event
 * @param entities the entities to be undisplayed.
 */
	public void fireEntitiesUndisplayed(Object source, InterfaceEntityList entities) {
		Object[] listeners = stageListenerList.getListenerList();
		StageEvent stageEvent = new StageEvent(source, entities);
		for(int i = listeners.length - 2; i>=0; i-=2) {
			((StageListener)listeners[i+1]).entitiesUndisplayed(stageEvent);
			}
		}
	}