package org.datamanager.userinterface.cerulean.model.menu;

import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.view.component.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.userinterface.cerulean.model.event.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;
import org.datamanager.userinterface.cerulean.model.data.storage.*;
import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;

/**
 * Create a new cluster check box menu.  This menu has contains cluster check
 * box menu items who are checked if the cluster is selected, and unchecked otherwise.
 *
 * @see InterfaceClusterCheckBoxMenuItem
 * @see InterfaceCluster
 * @see JMenu
 * @see JMenuItem
 *
 * @author Gordon Murphy (gpmurphy@indiana.edu)
 * @author Bryan Dawson (bdawson@indiana.edu)
 */

public class InterfaceClusterCheckBoxMenu extends JMenu implements MenuListener {
	private InterfaceEntityComponent entity;
	private Action action;
/**
 * Create a new Check Box Menu with no name field set.
 */
	public InterfaceClusterCheckBoxMenu() {
		super();
		addClustersToMenu();
		addMenuListener(this);
		}
/**
 * Create a new Check Box Menu.
 * @param text the name of the menu.
 */
	public InterfaceClusterCheckBoxMenu(String text) {
		this();
		setText(text);
		}
/**
 * Return an array of of items this menu contains.
 * @return the components this menu contains.
 */
	public InterfaceClusterCheckBoxMenuItem[] getInterfaceClusterMenuItems() {
		Component[] components = getMenuComponents();
		InterfaceClusterCheckBoxMenuItem[] clusters = new InterfaceClusterCheckBoxMenuItem[components.length];
		for (int i = 0; i <= clusters.length - 1; i++) {
			clusters[i] = (InterfaceClusterCheckBoxMenuItem)components[i];
			}
		return clusters;
		}
	public void addListener(InterfaceClusterCheckBoxMenuItem item) {}
	protected void addClustersToMenu() {
		ClusterList clusters = InterfaceClusterManager.getInstance().getClusters();
		for (int i = 0; i <= clusters.size() - 1; i++) {
			InterfaceCluster cluster = clusters.elementAt(i);
			InterfaceClusterCheckBoxMenuItem item = new InterfaceClusterCheckBoxMenuItem(cluster);
			add(item);
			addListener(item);
			if(cluster.isSelected())
				item.setState(true);
			else item.setState(false);
			}
		}
	public void menuSelected(MenuEvent e) {
		removeAll();
		addClustersToMenu();
		}
	public void menuDeselected(MenuEvent e) {
		}
	public void menuCanceled(MenuEvent e) {
		}
	}