package org.datamanager.userinterface.cerulean.model.menu;

import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.view.component.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.userinterface.cerulean.model.event.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;
import org.datamanager.userinterface.cerulean.model.data.storage.*;
import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;

/**
 * Creates a new Menu displaying all currently available clusters.
 */

public class InterfaceClusterMenu extends JMenu implements MenuListener {
	InterfaceEntityComponent entity;
	private Action action;
/**
 * Creates a new cluster menu with the title set to text.
 * @param text the name of the menu
 */
	public InterfaceClusterMenu(String text) {
		super();
		setText(text);
		addClustersToMenu();
		addMenuListener(this);
		}
	public InterfaceClusterMenuItem[] getInterfaceClusterMenuItems() {
		Component[] components = getMenuComponents();
		InterfaceClusterMenuItem[] clusters = new InterfaceClusterMenuItem[components.length];
		for (int i = 0; i <= clusters.length - 1; i++) {
			clusters[i] = (InterfaceClusterMenuItem)components[i];
			}
		return clusters;
		}
/**
 * Adds a cluster menu item to the menu.  Every cluster returned from InterfaceClusterManager
 * is displayed.  Calls addListener, to add any listeners to the menu, if needed.
 */
	public void addClustersToMenu() {
		ClusterList clusters = InterfaceClusterManager.getInstance().getClusters();
		for (int i = 0; i <= clusters.size() - 1; i++) {
			InterfaceCluster cluster = clusters.elementAt(i);
			InterfaceClusterMenuItem item = new InterfaceClusterMenuItem(cluster);
			add(item);
			addListener(item);
			}
		}
/**
 * Should be overridden to add any listeners to the menu items that are pertinent.
 * @param item the InterfaceClusterMenuItem to add a listener to.
 */
	public void addListener(InterfaceClusterMenuItem item) {}
	public void menuSelected(MenuEvent e) {
		removeAll();
		addClustersToMenu();
		}
	public void menuDeselected(MenuEvent e) {
		}
	public void menuCanceled(MenuEvent e) {
		}
	}