package org.datamanager.userinterface.cerulean.model.menu;

import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.view.component.*;
import org.datamanager.userinterface.cerulean.controller.action.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.userinterface.cerulean.model.menu.*;
import org.datamanager.userinterface.cerulean.model.event.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;
import org.datamanager.userinterface.cerulean.model.data.storage.*;
import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;

/**
 * A popup menu that the stage displays.
 * Currently, they display the following:<br>
 * <ul>
 * <li>Engage All Clusters</li>
 * <li>Disengage All Clusters</li>
 * <li>Engage Cluster (bring out another menu displaying clusters to engage)</li>
 * <li>Personalize</li>
 * <li>Show All Labels</li>
 */
 
public class StagePopupMenu extends InterfacePopupMenu implements ActionListener {
	private StageComponent stage;
	private JMenuItem personalize, createNewEntity;
	private JCheckBoxMenuItem showLabels;
	private InterfaceClusterCheckBoxMenu clusterMenu;
	public StagePopupMenu(StageComponent stage) {
		super();
		this.stage = stage;

		EngageAllClustersAction engageAction = new EngageAllClustersAction();
		JMenuItem engage = new JMenuItem();
		engage.addActionListener(engageAction);
		engage.setText("Engage All Clusters");
		add(engage);

		DisengageAllClustersAction disengageAction = new DisengageAllClustersAction();
		JMenuItem disengage = new JMenuItem();
		disengage.addActionListener(disengageAction);
		disengage.setText("Disengage All Clusters");
		add(disengage);

		clusterMenu = new ClusterSelectionMenu("Engage Cluster");
		add(clusterMenu);

		add(new JSeparator());
		personalize = new JMenuItem("Personalize");
		personalize.addActionListener(new PersonalizeAction(stage));
		add(personalize);

		
		add(new JSeparator());
		showLabels = new JCheckBoxMenuItem("Show All Labels");
		showLabels.addActionListener(this);
		add(showLabels);
		}

	public void actionPerformed(ActionEvent e) {
		if (e.getSource() == showLabels) {
			InterfaceEntityPeerTable entityTable = InterfaceEntityPeerTable.getInstance();
			ClusterList clusters = stage.getStage().getClusterList();
			if (showLabels.getState()) { //if true
				for (int i = 0; i <= clusters.size() - 1; i++) {
					InterfaceEntityList entities = clusters.elementAt(i).getInterfaceEntityList();
					for (int j = 0; j <= entities.size() - 1; j++) {
						InterfaceEntity entity = entities.elementAt(j);
						InterfaceEntityComponent entityComponent = entityTable.getPeer(entity);
						entityComponent.showLabel();
						}//end inside loop
					}//end outer loop
				}//end inner if
			else {
				for (int i = 0; i <= clusters.size() - 1; i++) {
					InterfaceEntityList entities = clusters.elementAt(i).getInterfaceEntityList();
					for (int j = 0; j <= entities.size() - 1; j++) {
						InterfaceEntity entity = entities.elementAt(j);
						InterfaceEntityComponent entityComponent = entityTable.getPeer(entity);
						entityComponent.removeLabel();
						}//end inner loop
					}//end outer loop
				}//end inner else
			}//end if
		}//end actionPerformed
	}//end class