package org.datamanager.userinterface.cerulean.model.personalize;

import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.userinterface.cerulean.model.colorchooser.*;
import org.datamanager.userinterface.cerulean.model.event.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;
import org.datamanager.userinterface.cerulean.model.data.storage.*;

import java.awt.*;
import java.io.*;
import java.net.*;
import java.awt.image.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.colorchooser.*;
import java.awt.geom.*;
import java.beans.*;

/**
 * A panel that allows a paint type to be chosen for a given personalizeable 
 * object.
 *
 * @see Personalizeable
 * @see Personalizer
 *
 * @author Gordon Murphy (gpmurphy@indiana.edu)
 * @author Bryan Dawson (bdawson@indiana.edu)
 */

public class PaintChooserPanel extends JPanel implements ActionListener, ChangeListener {
	private Personalizable entity;
	private JButton colorChooser, bitmapChooser;
	private ColorChooser chooser;
	public PaintChooserPanel(Personalizable entity) {
		super();
		this.entity = entity;
		colorChooser = new JButton("choose a color");
		colorChooser.addActionListener(this);
		bitmapChooser = new JButton("choose a texture");
		add(colorChooser);
		add(bitmapChooser);
		bitmapChooser.addActionListener(this);
		}
	public void showColorChooser() {
		chooser = new ColorChooser(entity);
		chooser.addChangeListener(this);
		Point location = colorChooser.getLocationOnScreen();
		Dimension size = colorChooser.getSize();
		chooser.setLocation(new Point(location.x+size.width, location.y));
		chooser.setSize(chooser.getPreferredSize());
		chooser.show();
		}
	public void showBitmapChooser() {
		JFileChooser fileChooser = new JFileChooser();
		int retVal = fileChooser.showOpenDialog(this);
		if (retVal == JFileChooser.APPROVE_OPTION) {
			try {
			File file = fileChooser.getSelectedFile();
			System.out.println("opening" + fileChooser.getSelectedFile());
			ImageIcon imageIcon = new ImageIcon(file.toURL());
			Image image = imageIcon.getImage();
			BufferedImage bufImage = new BufferedImage(50,50,BufferedImage.TYPE_INT_RGB);
			Graphics2D g2 = bufImage.createGraphics();
			g2.drawImage(image, 0,0,null);
			Paint currentPaint = new TexturePaint(bufImage, new Rectangle2D.Double(0,0,50,50));
			entity.setPaint(currentPaint);
			}
			catch(MalformedURLException e) {
				System.out.println("File incorrect");
				}
			}
		}
	public void actionPerformed(ActionEvent e) {
		if (e.getSource()==colorChooser) {
			showColorChooser();
			}
		else if (e.getSource() == bitmapChooser) {
			showBitmapChooser();
			}
		}
	public void stateChanged(ChangeEvent e) {
		entity.setPaint(chooser.getColor());
		}
	}