package org.datamanager.userinterface.cerulean.model.tree;

import org.datamanager.userinterface.cerulean.model.tree.InterfaceNode;
import org.datamanager.userinterface.cerulean.model.InterfaceCluster;
import org.datamanager.userinterface.cerulean.model.InterfaceClusterPeerTable;
import org.datamanager.userinterface.cerulean.model.menu.InterfaceClusterPopupMenu;
import javax.swing.JTree;

/**
 *This class inherites most of it's functionality from DefaultMutableTreeNode.
 *It is not much more than just a storage place for the InterfaceCluster that
 *is passed to it.  It's main function, however, is to serve as a node that the
 *EntityNodes can attach to.
 *
 *@author Bryan Dawson (bdawson@indiana.edu)
 *@author Gordon Murphy (gpmurphy@indiana.edu)
 *
 *@see org.datamanager.userinterface.cerulean.model.tree.EntityTreeModel
 *@see org.datamanager.userinterface.cerulean.model.tree.InterfaceNode
 *@see javax.swing.tree.DefaultMutableTreeNode
 */
//  Methods:
//  ~~~~~~~~
//  public ClusterNode(InterfaceCluster)
//          the only constructor, sets the cluster field
//  public void display()
//          currently, does nothing. 
//  public void select()
//          currently, does nothing.
//  public void handlePopup(JTree,int,int)
//          Display the InterfaceClusterPopupMenu corresponding to the
//  	    InterfaceCluster.
/////////////////////////////////////////////////////////////////////

public class ClusterNode extends InterfaceNode
   {
   //the InterfaceCluster this node represents
   private InterfaceCluster cluster;
   
   //the popup for this cluster
   private InterfaceClusterPopupMenu  menu;

   ////////////////////////////////////////////////////////
   /**
    *This is the only constructor, currently only sets the cluster field
    *@param cluster Sets the cluster field
    */
   public ClusterNode(InterfaceCluster cluster)
      {
      this.cluster = cluster;       
      }

   ////////////////////////////////////////////////////////////////
   /**
    *This method is used to display the cluster's name in the tree.
    *@return The string "Cluster: <InterfaceCluster's name>"
    */
   public String toString()
      {
      return new String("Cluster: "+cluster.getName());
      }
   ////////////////////////////////////////////////////////
   /**
    *Does nothing, but need not to be abstract.
    */
   public void display()
      {
      }
   ////////////////////////////////////////////////////////
   /**
    *Does nothing, but need not to be abstract.
    */
   public void select()
      {
      }
   ////////////////////////////////////////////////////////
   /**
    *Displays the InterfaceClusterPopupMenu corresponding to InterfacCluster
    *@param tree The component to display the popup over.
    *@param x The x-coordinate of the mouse click
    *@param y The y-coordinate of the mouse click
    */
   public void handlePopup(JTree tree, int x, int y)
     {
      menu = new InterfaceClusterPopupMenu(InterfaceClusterPeerTable.getInstance().getPeer(cluster));
     menu.show(tree,x,y);
     }      
      

  }//end of class




