package org.datamanager.userinterface.cerulean.model.tree;

import org.datamanager.userinterface.cerulean.model.tree.InterfaceNode;
import org.datamanager.userinterface.cerulean.model.menu.StagePopupMenu;
import org.datamanager.userinterface.cerulean.model.CircleManager;
import org.datamanager.userinterface.cerulean.view.component.StageComponent;
import javax.swing.JTree;

/**
 *This class inherites most of it's functionality from DefaultMutableTreeNode.
 *It's main function, however, is to serve as a node that the
 *ClusterNode's can attach to.
 *
 *@author Bryan Dawson (bdawson@indiana.edu)
 *@author Gordon Murphy (gpmurphy@indiana.edu)
 *
 *@see org.datamanager.userinterface.cerulean.model.tree.EntityTreeModel
 *@see org.datamanager.userinterface.cerulean.model.tree.InterfaceNode
 *@see javax.swing.tree.DefaultMutableTreeNode
 */
//  Methods:
//  ~~~~~~~~
//  public RootNode()
//          the only constructor, only sets the popup menu
//  public String toString()
//          Returns "Seleted Clusters:" if there are clusters selected (ie it 
//          is not a leaf) and "No Clusters Selected" otherwise.
//  public void display()
//  public void select()
//          Are currently not used, just needed to not be abstract.       
//  public void handlePopup(JTree, int, int)
//         Display a StagePopupMenu.  NOTE A KNOWN BUG: The StagePopupMenu 
//         contains a JCheckBoxMenu item.  The if the state of this menu item 
//         is changed via this method or through clicking on the stage, then
//         the other StagePopupMenu is not changed. 
/////////////////////////////////////////////////////////////////////
public class RootNode extends InterfaceNode
   {
   //The popup menu
   private StagePopupMenu popup;
   

   ////////////////////////////////////////////////////////
   /**
    *This is the only constructor, currently only sets the popup menu
    */
   public RootNode()
      {
      super();
      popup = new StagePopupMenu(CircleManager.getInstance().getStage());
      }

   ////////////////////////////////////////////////////////
   /** 
    *do nothing, but needed not to be abstract.
    */
   public void display()
      {}
   ////////////////////////////////////////////////////////
   /** 
    *do nothing, but needed not to be abstract.
    */
   public void select()
       {}
   ////////////////////////////////////////////////////////
   /** 
    * Display a StagePopupMenu.  NOTE A KNOWN BUG: The StagePopupMenu 
    *contains a JCheckBoxMenu item.  The if the state of this menu item 
    *is changed via this method or through clicking on the stage, then
    *the other StagePopupMenu is not changed. 
    *@param tree The component that the popup is displayed over.
    *@param x The x-coordinate of the mouse click.
    *@param y The y-coordinate of the mouse click.
    */
   public void handlePopup(JTree tree,int x, int y)
      {
      popup.show(tree, x, y);
      }
      
   //////////////////////////////////////////////////////////
   /**
    * Returns the string to be displayed on the tree.  Depends on whether this
    *node is a leaf.
    *@return "No Clusters Selected" if it is a leaf, or "Selected Clusters:" otherwise.
    */
   public String toString()
      {
      if(isLeaf())
         return new String("No Clusters Selected");
      else
      	 return new String("Selected Clusters:");
      }
      
  }//end of class




