package org.datamanager.userinterface.cerulean.sounds;

import java.net.URL;
import java.net.MalformedURLException;
import org.datamanager.userinterface.cerulean.sounds.Orchestra;

/**
 *This class is a only needed due to the poor sound handling code for JDK 1.2
*The JDK 1.2 sound code for applications is handled through a static method
*newAudioClip(URL) in the java.applet.Applet class.  The sound API, however, 
*secretly relies on the calling thread not dieing.  That is the whole purpose 
*of this class, to not die.  Any requests for sounds go through this class. 
*To make sure that this class is always alive a reference to the only Object of
*this class is kept in the CeruelanFrame, thus making sure that the  calling 
*thread (ie this class) does not die.  The  class that it currently uses to
*play and load sounds is 
*org.datamanager.userinterface.cerulean.sounds.Orchestra.  
*SoundRequestHandler is the encapsulation for the Orchestra class, allowing 
*for it to be replaced in the future if a better way is found.  
*
*@author Bryan Dawson (bdawson@indiana.edu)
*@author Gordon Murphy (gpmurphy@indiana.edu)
*
*@see org.datamanager.userinterface.cerulean.sounds.Orchestra
*@see java.applet.AudioClip
*@see java.net.URL
*
*/

//  Methods:
//  ~~~~~~~
//  private SoundRequestHandler()
//        This is made private so that there is only one copy of this class. 
//        This was done so that there is always a copy of the object kept
//        alive through the CerleanFrame.
//  public SoundRequestHandler getInstance()
//        This method is used to get the one instance of this class.  Lets us 
//        control the number of copies to one. 
//  public void load(String)
//        The String is the name of the sound file.  The file name is passed to
//        the Orchestra for loading. 
//  public void play(String)
//        The String parameter is the name of the sound file to be played.
//        It is just passed on to the Orchestra class at the current time. 
//////////////////////////////////////////////////////////////////



public class SoundRequestHandler
   {
   
   /**
    *This the one and only instance of this class.
    */
   private static SoundRequestHandler handler;
       
   /**
    *This is the Orchestra that actually does all of the work
    */
   private Orchestra band;

   /**
    *This the URL of the directory where the sounds are located
    */
   private URL baseURL;

   //////////////////////////////////////////////////////////
       /**
	*This is the only constructor, it creates an Orchestra with baseURL
	* pointing to ./org/datamanager/userinterface/cerulean/sounds
	*/
   public SoundRequestHandler()
      {
	  String currentDirectory = System.getProperty("user.dir");
	  String fileSeparator = System.getProperty("file.separator");
	  baseURL = null;
	  
	  //load the the URL of the sounds directory
          try
                       {
                       baseURL = new URL("file:" + currentDirectory +
                               fileSeparator + "org"+ fileSeparator +
			       "datamanager"+ fileSeparator +"userinterface"
			       + fileSeparator + "cerulean" +fileSeparator 
			       +"sounds" + fileSeparator);
                       }
          catch (MalformedURLException ignored) {}
	  
	  //create the Orchestra with that directory
	  band = new Orchestra(baseURL);

      }

   ////////////////////////////////////////////////////////////
       /**
	* Get the one and only instance of this class.
	*/
   public static SoundRequestHandler getInstance()
      {
	  //see if an instance has been created yet
	  if(handler == null)
	      handler = new SoundRequestHandler();
	  return handler;
      }

   //////////////////////////////////////////////////////////////
       /**
	*Load the sound corresponding to the given string.  Orchestra
	*stores it in a hashtable for future reference.
	*/
   public void load(String soundName)
      {
	  //just sends the string to Orchestra
	  band.load(soundName);
      }

   //////////////////////////////////////////////////////////////
       /**
	*Play the sound corresponding to the given string.
	*/
   public void play(String soundName)
      {
	  //just send to the Orchestra
	  band.play(soundName);
	  //pause();

      }

}//end of class
