/*
class org.datamanager.userinterface.cerulean.model.Abyss
KnownSpace: Cerulean

Authors:
~~~~~~~~
Gordon Murphy, gpmurphy@indiana.edu
Bryan Dawson, bdawson@indiana.edu
*/

package org.datamanager.userinterface.cerulean.view.component;

import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.Shape;
import javax.swing.BorderFactory;
import javax.swing.JComponent;
import javax.swing.JLayeredPane;
import org.datamanager.userinterface.cerulean.controller.drop.AbyssDropListener;
import org.datamanager.userinterface.cerulean.controller.mouse.AbyssMouseListener;
import org.datamanager.userinterface.cerulean.controller.entity.AbyssEntityListener;
import org.datamanager.userinterface.cerulean.model.CircleManager;
import org.datamanager.userinterface.cerulean.model.Abyss;
import org.datamanager.userinterface.cerulean.model.InterfaceEntityManager;

/**
 *
 * The abyss is the graphical representation of a kind of "trash can".  
 * Items can be dragged and dropped into the abyss, where they "disappear."
 * In essence though, the abyss is just a subclass of Circle with a null
 * layout into which any Swing JComponent can be dragged.
 *
 * @see Circle
 * @see CircleManager
 * @see InterfaceEntityManager
 * @see CircleIcon
 * @see AbyssDropListener
 *
 * @version 1.0
 * @author Gordon Murphy, gpmurphy@indiana.edu
 * @author Bryan Dawson, bdawson@indiana.edu 
 */

////////////////////////////////////////////////////////////////////////////////
public class AbyssComponent extends Circle {
	/**
	 * Creates a new Abyss with default settings
	 */
	private Abyss abyss;
	public AbyssComponent() {
		super();
		setLayout(null);
		AbyssDropListener listener = new AbyssDropListener(this);
		setName("the Abyss");
		setToolTipText(getName());
		abyss = new Abyss();
		CircleManager circleManager = CircleManager.getInstance();
		circleManager.setAbyss(this);
		setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 0));
		getIcon().setPaint(Color.black);
		InterfaceEntityManager entityManager = InterfaceEntityManager.getInstance();
		entityManager.addEntityListener(new AbyssEntityListener(this));
		addMouseListener(new AbyssMouseListener(this));
		}

////////////////////////////////////////////////////////////////////////////////
	/**
	 * Returns the current shape of the abyss
	 * @return the current Shape representing the abyss
	 */
	public Shape getAbyssShape() {
		return circleIcon.getIconShape();
		}
	public Abyss getAbyss() {
		return abyss;
		}
	}