/*
KnownSpace: Cerulean
class org.datamanager.userinterface.cerulean.model.Buffer

Authors:
~~~~~~~~
Gordon Murphy, gpmurphy@indiana.edu
Bryan Dawson, bdawson@indiana.edu
*/
package org.datamanager.userinterface.cerulean.view.component;

import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.Shape;
import javax.swing.BorderFactory;
import javax.swing.JComponent;
import javax.swing.JLayeredPane;
import org.datamanager.userinterface.cerulean.controller.cluster.BufferClusterListener;
import org.datamanager.userinterface.cerulean.controller.drop.BufferDropListener;
import org.datamanager.userinterface.cerulean.controller.mouse.BufferMouseListener;
import org.datamanager.userinterface.cerulean.model.Buffer;
import org.datamanager.userinterface.cerulean.model.InterfaceClusterManager;
import org.datamanager.userinterface.cerulean.view.layout.StageLayout;

/**
 * The buffer is the graphical representation of a kind of "clip board".  
 * Items can be dragged and dropped into the buffer, where they are stored.
 * Once items are stored in the buffer, they cannot be dragged directly onto
 * the stage, rather, they must be dragged to a cluster.
 *
 * @see Circle
 * @see CircleManager
 * @see InterfaceEntityManager
 * @see CircleIcon
 * @see BufferDropListener
 * @see BufferEntityListener
 *
 * @version 1.0
 * @author Gordon Murphy, gpmurphy@indiana.edu
 * @author Bryan Dawson, bdawson@indiana.edu 
 */

public class BufferComponent extends Circle {
	private Buffer buffer;
/**
 * Creates a new BufferComponent.  This listens for DragAndDropEvents and 
 * accepts InterfaceEntityComponents.
 */
	public BufferComponent() {
		super();
		buffer = new Buffer();
		setLayout(new StageLayout());
		BufferDropListener listener = new BufferDropListener(this);
		setName("the Buffer");
		setToolTipText(getName());
		setBorder(BorderFactory.createEmptyBorder(30, 30, 30, 30));
		circleIcon.setPaint(new Color(0, 153, 153));
		addMouseListener(new BufferMouseListener(this));
		InterfaceClusterManager clusterManager = InterfaceClusterManager.getInstance();
		clusterManager.addClusterListener(new BufferClusterListener(this));	
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Returns the Shape that defines the buffers bounds.
 * @return the shape defining the buffers bounds
 */
	public Shape getBufferShape() {
		return getIcon().getIconShape();
		}
	public Buffer getBuffer() {
		return buffer;
		}
	}