/*
class org.datamanager.userinterface.cerulean.model.Circle

Authors:
~~~~~~~~
Gordon Murphy, gpmurphy@indiana.edu
Bryan Dawson, bdawson@indiana.edu
*/

package org.datamanager.userinterface.cerulean.view.component;
import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.view.icon.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.awt.geom.*;

/**
 * Circle is the base class for all components in the "circle": the stage,
 * buffer, and abyss.  It defines a layered pane capable of holding any
 * InterfaceEntity.
 *
 * @see Abyss
 * @see Buffer
 * @see StageComponent
 *
 * @version 1.0
 * @author Gordon Murphy, gpmurphy@indiana.edu
 * @author Bryan Dawson, bdawson@indiana.edu 
 */
public class Circle extends JLayeredPane implements Personalizable {
	protected CircleIcon circleIcon;
	protected String name;
////////////////////////////////////////////////////////////////////////////////
/**
 * Creates a new Circle that is visible and not opaque
 */
	public Circle() {
		setIcon(new CircleIcon(new Color(100, 100, 100)));
		setVisible(true);
		setOpaque(false);
		setPreferredSize(new Dimension(300, 300));
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Overrides paintComponent to call its icon representation's paintIcon method
 */

	public void paintComponent(Graphics g) {
		super.paintComponent(g);
		Component c = getParent();
		setPreferredSize(new Dimension(c.getWidth(), c.getHeight()));
		Graphics2D g2 = (Graphics2D)g;

		//turn antialiasing on: looks much, much, much better
		RenderingHints hints;
		hints = new RenderingHints(RenderingHints.KEY_ANTIALIASING,
							RenderingHints.VALUE_ANTIALIAS_ON);
		g2.addRenderingHints(hints);
		
		circleIcon.paintIcon(this, g2, 0, 0);
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Sets the Icon that represents the component
 * @param icon the icon that to represent the circle
 */
	public void setIcon(CircleIcon icon) {
		circleIcon = icon;
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Returns the icon that represents the graphical view of the circle
 * @return the icon representing the circle
 */
	public CIcon getIcon() {
		return circleIcon;
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Returns the bounding shape of the component.
 * @return the bounding shape of the component
 */
	public Shape getIconShape() {
		return circleIcon.getIconShape();
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Overrides contains to only return true if a point is contained within the
 * icons bounding shape
 * @param x the x coordinate that may be contained within the component
 * @param y the y coordinate that may be contained within the component
 * @return true if the icon contains the point, false otherwise
 */
	public boolean contains(int x, int y) {
		return circleIcon.getIconShape().contains(x,y);
		}

////////////////////////////////////////////////////////////////////////////////
	/**
	 * Returns a point converted from the Abyss's coordinate system to the
	 * source's coordinate system
	 * @param source the calling component
	 * @param x the x coordinate to convert
	 * @param y the y coordinate to convert
	 * @return the converted point
	 */
	public Point convertPoint(Component source, int x, int y) {
		return SwingUtilities.convertPoint(this, x, y, source);
		}
	public void setPaint(Paint paint) {
		getIcon().setPaint(paint);
		repaint();
		}
	public void setShape(Shape shape) {
		getIcon().setIconShape(shape);
		repaint();
		}
	public void setIcon(CIcon icon) {
		//does nothing for now...
		}
	public Paint getPaint() {
		return getIcon().getPaint();
		}
	public Shape getShape() {
		return getIcon().getIconShape();
		}
	public void setName(String name) {
		this.name = name;
		setToolTipText(name);
		}
	public String getName() {
		return name;
		}
	}