/*
class org.datamanager.userinterface.cerulean.model.CirclePane
KnownSpace: Cerulean

Authors:
~~~~~~~~
Gordon Murphy, gpmurphy@indiana.edu
Bryan Dawson, bdawson@indiana.edu
*/

package org.datamanager.userinterface.cerulean.view.component;
import org.datamanager.userinterface.cerulean.view.icon.*;

import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.model.*;
import java.awt.Component;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.BorderLayout;
import java.awt.RenderingHints;
import javax.swing.JLayeredPane;
import java.awt.event.ComponentAdapter;
import java.awt.event.ComponentEvent;

/**
 * The base class for all component panes to be added to a CRootPane.  
 * CirclePane allows events and actions to pass through to child components or
 * components beneath it.
 *
 * @see JLayeredPane
 *
 * @version 1.0
 * @author Gordon Murphy, gpmurphy@indiana.edu
 * @author Bryan Dawson, bdawson@indiana.edu 
 */

public class CirclePane extends JLayeredPane {
	private int currentHeight;
	private int currentWidth;
////////////////////////////////////////////////////////////////////////////////
/**
 * Creates a new CirclePane
 */
	public CirclePane() {
		super();
		currentWidth = 300;
		currentHeight = 300;
		setLayout(new BorderLayout());
		setVisible(true);
		setOpaque(false);
		}

////////////////////////////////////////////////////////////////////////////////
	public void paintComponent(Graphics g) {
		super.paintComponent(g);
		Graphics2D g2 = (Graphics2D)g;

		//turn antialiasing on: looks much, much, much better
		RenderingHints hints;
		hints = new RenderingHints(RenderingHints.KEY_ANTIALIASING,
						 RenderingHints.VALUE_ANTIALIAS_ON);
		g2.addRenderingHints(hints);
		}

/**
 * Overridden so that mouse events and other actions pass through the parts of
 * the panel that do not contain a child.
 * @param x x coordinate to find component at
 * @param y y coordinate to find component at
 * @return the component at the given coordinates or null if none is found
 */
	public Component findComponentAt(int x, int y) {
		Component c = super.findComponentAt(x,y);
		if (c==this) return null;
		else return c;
		}
	}