/*
class org.datamanager.userinterface.cerulean.model.InterfaceClusterComponent
KnownSpace: Cerulean

Authors:
~~~~~~~~
Gordon Murphy, gpmurphy@indiana.edu
Bryan Dawson, bdawson@indiana.edu
*/
package org.datamanager.userinterface.cerulean.view.component;

import org.datamanager.userinterface.cerulean.view.icon.*;
import org.datamanager.userinterface.cerulean.controller.cluster.InterfaceClusterClusterListener;
import org.datamanager.userinterface.cerulean.controller.drop.InterfaceClusterDropListener;
import org.datamanager.userinterface.cerulean.controller.mouse.InterfaceClusterMouseListener;
import org.datamanager.userinterface.cerulean.controller.action.InterfaceClusterActionListener;
import org.datamanager.userinterface.cerulean.model.InterfaceCluster;
import org.datamanager.userinterface.cerulean.model.InterfaceClusterManager;
import org.datamanager.userinterface.cerulean.model.InterfaceClusterPeerTable;
import org.datamanager.userinterface.cerulean.model.data.storage.InterfaceEntityList;
//import org.datamanager.userinterface.cerulean.model.data.storage.EntityList;

import java.awt.Paint;
import java.awt.Color;

/**
 * InterfaceClusterComponent is the visual representation of a InterfaceCluster.  
 * InterfaceClusterComponent inherits all of the methods of Tab, which it extends.
 * By default the tab is made white.
 *
 * @see InterfaceCluster
 * @see InterfaceClusterManager
 * @see InterfaceClusterPeerTable
 * @see InterfaceClusterDropListener
 * @see InterfaceClusterClusterListener
 * @see InterfaceClusterEntityListener
 * @see InterfaceEntityList
 *
 * @version 1.0
 * @author Gordon Murphy, gpmurphy@indiana.edu
 * @author Bryan Dawson, bdawson@indiana.edu 
 */

public class InterfaceClusterComponent extends Tab {
	//The InterfaceCluster represented
	private InterfaceCluster cluster;
	public static final Color DEFAULT_CLUSTER_COLOR = Color.white;
////////////////////////////////////////////////////////////////////////////////
/**
 * Creates a InterfaceClusterComponent containing an empty cluster and a default color 
 * of white
 */
	public InterfaceClusterComponent() {
		this(new InterfaceCluster());
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Creates a InterfaceClusterComponent containing the specified cluster and a default
 * color of White
 * @param cluster the specified cluster which this will represent
 */
	public InterfaceClusterComponent(InterfaceCluster cluster) {
		this(cluster, DEFAULT_CLUSTER_COLOR);
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Creates a InterfaceClusterComponent containing the specified cluster and painted the
 * specified Paint.
 * @param cluster the cluster to be represented
 * @param paint the paint to make this InterfaceClusterComponent
 */
	public InterfaceClusterComponent(InterfaceCluster cluster, Paint paint) {
		super(cluster.getName(), paint); //call super

		//Listen for selection and unselection and set the InterfaceCluster 
		//accordingly
		addActionListener(new InterfaceClusterActionListener(this));

		//Listen for popup menu events
		addMouseListener(new InterfaceClusterMouseListener(this));

		//set the cluster
		this.cluster = cluster;
		
		//register this as the peer of the InterfaceCluster
		InterfaceClusterPeerTable.getInstance().registerPeer(cluster, this);
	
		//Add a drop listener to detect any entities dropped on us	
		InterfaceClusterDropListener listener = new InterfaceClusterDropListener(this);

		//Listen for all cluster events
		InterfaceClusterManager clusterManager = InterfaceClusterManager.getInstance();
		clusterManager.addClusterListener(new InterfaceClusterClusterListener(this));
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Creates a InterfaceClusterComponent containing an empty InterfaceCluster with the specified
 * name and a default color of white
 * @param name the name of the cluster to be made
 */
	public InterfaceClusterComponent(String name) {
		this(new InterfaceCluster(name));
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Creates a InterfaceClusterComponent containing an empty InterfaceCluster with the specified
 * name, and painted the specified paint
 * @param name the name of the cluster to be made
 * @param paint the paint type
 */
	public InterfaceClusterComponent(String name, Paint paint) {
		this(new InterfaceCluster(name), paint);
		}

////////////////////////////////////////////////////////////////////////////////
/**
 * Returns the InterfaceCluster this represents
 * @return the InterfaceCluster the InterfaceClusterComponent represents
 */
	public InterfaceCluster getCluster() {
		return cluster;
		}
////////////////////////////////////////////////////////////////////////////////
/**
 * Sets the InterfaceCluster represented by the component
 * @param cluster the InterfaceCluster the InterfaceClusterComponent represents
 */
	private void setCluster(InterfaceCluster cluster) {
		this.cluster = cluster;
		}
	}