package org.datamanager.userinterface.cerulean.view.component;

import org.datamanager.userinterface.cerulean.view.icon.*;

import org.datamanager.userinterface.cerulean.view.*;
import org.datamanager.userinterface.cerulean.view.viewer.*;
import org.datamanager.userinterface.cerulean.controller.drop.*;
import org.datamanager.userinterface.cerulean.controller.mouse.*;
import org.datamanager.userinterface.cerulean.controller.entity.*;
import org.datamanager.userinterface.cerulean.model.*;
import org.datamanager.userinterface.cerulean.model.event.*;
import org.datamanager.userinterface.cerulean.model.data.transfer.*;

import java.awt.*;
import java.awt.event.*;
import java.awt.datatransfer.*;
import java.awt.dnd.*;
import javax.swing.*;
import java.awt.geom.*;
import java.io.*;
/**
 * 
 */
public class InterfaceEntityComponent extends JComponent implements Personalizable, Displayable {
	private int width, height;
	private String localFlavor;
	private Transferable transferable;
	private CIcon currentIcon;
	private InterfaceEntityDragListener dragListener;
	private InterfaceEntity entity;
	private double ratioX = 1, ratioY = 1;
	private int weight;
	private CeruleanToolTip cLabel;
	private boolean isLabelDisplayed;
	private boolean isSelected;
	public InterfaceEntityComponent() {
  		this(Color.white, new InterfaceEntity());
		}
	public InterfaceEntityComponent(InterfaceEntity entity) {
		this(Color.white, entity);
		}
	public InterfaceEntityComponent(Paint paint) {
		this(paint, new InterfaceEntity());
		}
	public InterfaceEntityComponent(Paint paint, InterfaceEntity entity) {
		this.entity = entity;
		setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
		//setEntityName(entity.getName());
		setCurrentIcon(new InterfaceEntityIcon(paint));
		width = getCurrentIcon().getIconWidth();
		height = getCurrentIcon().getIconHeight();
		setSize(width,height);
		setVisible(true);
		setCeruleanToolTip(new CeruleanToolTip(getEntityName()));
		setToolTipText(getEntityName());
		
		//transferable = new InterfaceEntityTransferable(this);
		
		dragListener = new InterfaceEntityDragListener(this);
		InterfaceEntityPeerTable.getInstance().registerPeer(entity, this);
		//InterfaceEntityManager.getInstance().addEntityListener(new InterfaceEntityEntityListener(this));
		entity.addEntityListener(new InterfaceEntityEntityListener(this));
		InterfaceEntityMouseListener mouseListener = new InterfaceEntityMouseListener(this);
		addMouseListener(mouseListener);
		}
	public Point getClustering(int width, int height) {
		double seed = Math.random();
		int x = (int)(seed * (double)width);
		seed = Math.random();
		int y = (int)(seed * (double)height);
		Point location = new Point(x,y);
		return location;
		}
	public void paintEntity(Graphics g) {
		getCurrentIcon().paintIcon(this,g, 0, 0);
		if (isVisible()) {
			updateLabel();
			}
		else removeLabel();
		}
	public void paintComponent(Graphics g) {
		getCurrentIcon().paintIcon(this,g, 0, 0);
		if (isVisible()) {
			updateLabel();
			}
		else removeLabel();
		}
	public void setSelected(boolean isSelected) {
		this.isSelected = isSelected;
		repaint();
		}
	public boolean isSelected() {
		return isSelected;
		}
	public void setCurrentIcon(CIcon icon) {
		currentIcon = icon;
		}
	public CIcon getCurrentIcon() {
		return currentIcon;
		}
	public String getEntityName() {
		return getInterfaceEntity().getEntityName();
		}
	public void setEntityName(String entityName) {
		getInterfaceEntity().setEntityName(entityName);
		}
	public void setPaint(Paint paint) {
		CIcon icon = getCurrentIcon();
		icon.setPaint(paint);
		repaint();
		}
	public void setShape(Shape shape) {
		CIcon icon = getCurrentIcon();
		icon.setIconShape(shape);
		Dimension newSize = shape.getBounds().getSize();
		setSize(newSize);
		repaint();
		}
	public void setName(String name) {
		setToolTipText(name);
		setEntityName(name);
		getCeruleanToolTip().setTipText(name);
		getCeruleanToolTip().repaint();
		}
	public void setIcon(CIcon icon) {
		setCurrentIcon(icon);
		invalidate();
		repaint();
		}
	public CIcon getIcon() {
		return getCurrentIcon();
		}
	public Paint getPaint() {
		return getCurrentIcon().getPaint();
		}
	public String getName() {
		return getEntityName();
		}
	public Shape getShape() {
		return getCurrentIcon().getIconShape();
		}
	public void setWeight(int weight) {
		this.weight = weight;
		}
	public int getWeight() {
		return weight;
		}
	public InterfaceEntity getInterfaceEntity() {
		return entity;
		}
	public boolean contains(int x, int y) {
		CIcon currentIcon = getCurrentIcon();
		CIcon entityIcon = currentIcon;
		return entityIcon.getIconShape().contains(x,y);
		}
	public Transferable getTransferable() {
		return transferable;
		}
	public void openEntity() {
		DisplayFrame display = new DisplayFrame();
		display.display(entity.getValue());
		}
	public CeruleanToolTip getCeruleanToolTip() {
		return cLabel;
		}
	public void setCeruleanToolTip(CeruleanToolTip cLabel) {
		this.cLabel = cLabel;
		}
	public void updateLabel() {
		Rectangle bounds = getBounds();
		int xPosition = bounds.x+bounds.width/2;
		int yPosition = bounds.y+bounds.height/2;
		getCeruleanToolTip().setLocation(xPosition,yPosition);
		}
	public void showLabel() {
		if (!isLabelDisplayed) {
			CeruleanToolTip label = getCeruleanToolTip();
			Rectangle bounds = getBounds();
			isLabelDisplayed = true;
			label.showLabel(this, new Point(bounds.x+(bounds.width)/2, bounds.y+(bounds.height)/2));
			}
		}
	public void removeLabel() {
		if (isLabelDisplayed) {
			isLabelDisplayed = false;
			getCeruleanToolTip().hideLabel();
			}
		}
	public void addNotify() {
		super.addNotify();
		if (isLabelDisplayed)
			showLabel();
		}
	public void removeNotify() {
		super.removeNotify();
		if (getCeruleanToolTip().isDisplayed()) {
			removeLabel();
			isLabelDisplayed = true;
			}
		Container container = getParent();
		JComponent parent = (JComponent)container;
		parent.repaint(getBounds());
		}
	public JToolTip createToolTip() {
		return getCeruleanToolTip();
		}
	}
