package org.datamanager.userinterface.cerulean.view.layout;
import org.datamanager.userinterface.cerulean.view.component.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.accessibility.*;
import java.util.Vector;
import java.io.Serializable;

public class CRootLayout implements LayoutManager2, Serializable {
	private JComponent buttonPane, tabPane, stagePane, abyssPane, bufferPane, glassPane;
	private CRootPane rootPane;
	public CRootLayout(CRootPane rootPane) {
		this.rootPane = rootPane;
		}
	public Dimension preferredLayoutSize(Container parent) {
		Dimension rd, mbd;
		Insets i = rootPane.getInsets();
		rd = rootPane.getParent().getSize();
		
		return new Dimension(rd.width + i.left + i.right, 
                                 rd.height + i.top + i.bottom);
		}

        /**
         * Returns the minimum amount of space the layout needs.
         *
         * @param the Container for which this layout manager is being used
         * @return a Dimension object containing the layout's minimum size
         */ 
        public Dimension minimumLayoutSize(Container parent) {
            Dimension rd;
            Insets i = rootPane.getInsets();
            rd = parent.getSize();
            return new Dimension(rd.width + i.left + i.right, 
                        rd.height + i.top + i.bottom);
        }

        /**
         * Returns the maximum amount of space the layout can use.
         *
         * @param the Container for which this layout manager is being used
         * @return a Dimension object containing the layout's maximum size
         */ 
        public Dimension maximumLayoutSize(Container target) {
            Dimension rd, mbd;
            Insets i = rootPane.getInsets();

            // This is silly, but should stop an overflow error
            rd = new Dimension(Integer.MAX_VALUE, 
                        Integer.MAX_VALUE - i.top - i.bottom - 1);
            
            return new Dimension(rd.width + i.left + i.right,
                                         rd.height + i.top + i.bottom);
        }
        
        /**
         * Instructs the layout manager to perform the layout for the specified
         * container.
         *
         * @param the Container for which this layout manager is being used
         */ 
        public void layoutContainer(Container parent) {
            Rectangle b = rootPane.getParent().getBounds();
            Insets i = rootPane.getInsets();
            int contentY = 0;
            int w = b.width - i.right - i.left;
            int h = b.height - i.top - i.bottom;
		buttonPane = rootPane.getButtonPane();
		tabPane = rootPane.getTabPane();
		stagePane = rootPane.getStagePane();
		abyssPane = rootPane.getAbyssPane();
		bufferPane = rootPane.getBufferPane();
		glassPane = rootPane.getGlassPane();

		if(glassPane != null) {
			glassPane.setBounds(i.left, i.top, w, h);
			}
		if(buttonPane != null) {
			buttonPane.setBounds(i.left, i.top, w, h);
			}
		if(tabPane != null) {
			tabPane.setBounds(i.left, i.top, w, h);
			}
		if(stagePane != null) {
			stagePane.setBounds(i.left, i.top, w, h);
			}
		if(abyssPane != null) {
			abyssPane.setBounds(i.left, i.top, w, h);
			}
		if(bufferPane != null) {
			bufferPane.setBounds(i.left, i.top, w, h);
			}
        }        
        public void addLayoutComponent(String name, Component comp) {}
        public void removeLayoutComponent(Component comp) {}
        public void addLayoutComponent(Component comp, Object constraints) {}
        public float getLayoutAlignmentX(Container target) { return 0.0f; }
        public float getLayoutAlignmentY(Container target) { return 0.0f; }
        public void invalidateLayout(Container target) {}
    }
