package org.datamanager.userinterface.cerulean.view.search;

import org.datamanager.event.WebSearchEvent;
import org.datamanager.event.NewsGroupDownloadEvent;
import org.datamanager.userinterface.cerulean.model.kernel.KernelProxy;
import org.datamanager.kernel.Pool;
import javax.swing.JFrame;
import javax.swing.JTextField;
import javax.swing.JComboBox;
import javax.swing.JCheckBox;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.event.ItemListener;
import java.awt.event.ItemEvent;
import java.awt.GridLayout;
import java.awt.Window;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.awt.Toolkit;

/**
 *
 *This class displays to the user several advanced search options.  At the 
 *moment those advanced options are: Search the web, and new group search.
 *For these options the user must specify certain information.
 *
 *@author Bryan Dawson (bdawson@indiana.edu)
 *@author Gordon Murphy (gpmurphy@indiana.edu)
 *
 *@see org.datamanager.userinterface.cerulean.view.search.SearchPane
 */

//  methods:
//  ~~~~~~~~
//  public AdvancedSearchFrame()
//       This constructor puts together all of the elements of the frame
//  public AdvancedSearchFrame(String)
//       Specifies the String for the keywords JTextField
//  public void actionPerformed(ActionEvent)
//       This causes the searches to happen.
//  public void setWebFields()
//  public void setNewsFields()
//       These methods are set the fields either enabeled or not, depending on 
//       whether web search or newsgroup download is selected.
//  public void execute()
//       This method adds the events to the pool (via KernelProxy), 
//       which in turn 
//       cause either a web search or a newsgroup download to occur.
//  public void exit()
//       This method makes sure that the frame is disposed of to free up
//        resources
//////////////////////////////////////////////////////////////////////////

public class AdvancedSearchFrame extends JFrame implements ActionListener
   {
       private JCheckBox news, web;

       //for user input 
       private JTextField keywords, newsServer, newsGroup;

       //select the search engine to do a websearch through
       private JComboBox searchEngines;

       private JButton okay, cancel;

       String[] displayEngines, engines; 
       public static final String DEFAULT_STRING = "";
       public static final int NUM_COLUMNS = 20;
       //////////////////////////////////////////////////////////////
       /** This constructor uses the default String of "" to call the 
	*  other constructor.
	*/
       public AdvancedSearchFrame()
          {
	      this(DEFAULT_STRING);
	  }
       /**
	* This constructor uses the given string to fill the keywords
	* textfield.
	*@param string String to be loaded into the keywords field
	*/
       public AdvancedSearchFrame(String string)
          {
	      super("Advanced Options");

	      //setup the text fields.
	      this.keywords = new JTextField(string, NUM_COLUMNS);
	      newsServer = new JTextField(NUM_COLUMNS);
	      newsGroup = new JTextField(NUM_COLUMNS);
	    
	      //setup the JCheckBoxes
	      news = new JCheckBox("Download News Group", false);
	      web = new JCheckBox("Web Search", true);
	      
	      //setup the JComboBox with the search engines avaiable
	      //I know this looks funny, but it would give me errors otherwise
	      String[] displayEngines = {"GOOGLE", "DEJANEWS",
					      "ALTAVISTA","YAHOO","EXCITE",
					      "WEBCRAWLER"};
	      this.displayEngines = displayEngines;
	      String[] engines =  {WebSearchEvent.GOOGLE,
					   WebSearchEvent.DEJANEWS,
					   WebSearchEvent.ALTAVISTA,
					   WebSearchEvent.YAHOO,
					   WebSearchEvent.EXCITE,
					   WebSearchEvent.WEBCRAWLER};
	      this.engines = engines;
	      searchEngines = new JComboBox(displayEngines);
	      //setup the buttons
	      okay = new JButton("OK");
	      cancel = new JButton("Cancel");

	      //setup the size, image, and layout
	      this.setSize(400,200);
	      String separator = System.getProperty("file.separator");
	      this.setIconImage( Toolkit.getDefaultToolkit().getImage(
		   "org"+separator+"datamanager"+separator+"userinterface"
		   +separator+"cerulean"+separator+"images"+separator+
		   "icon.gif") );
	      this.getContentPane().setLayout(new GridLayout(6,2));

	      //enable only the web search items
	      newsServer.setEnabled(false);
	      newsGroup.setEnabled(false);
	      
	      //add the items
	      getContentPane().add(web);
	      getContentPane().add(news);
	      getContentPane().add(new JLabel("Keywords"));
	      getContentPane().add(keywords);
	      getContentPane().add(new JLabel("Search Engines"));
	      getContentPane().add(searchEngines);
	      getContentPane().add(new JLabel("News Group"));
	      getContentPane().add(newsGroup);
	      getContentPane().add(new JLabel("News Server"));
	      getContentPane().add(newsServer);
	      getContentPane().add(okay);
	      getContentPane().add(cancel);

	      //add the listeners
	      web.addActionListener(this);
	      news.addActionListener(this);
	      okay.addActionListener(this);
	      cancel.addActionListener(this);
	      
	      addWindowListener(new WindowAdapter(){
		     public void windowClosed(WindowEvent event)
		      {
			  Window window = event.getWindow();
			  window.setVisible(false);
			  // window.dispose();
		      }});
	  }
      	
       ///////////////////////////////////////////////////////////////
       /**
	*From the ActionListener interface. Determines which button was 
	*pushed and does the corresponing action.
	*@param event Fired when one of the buttons is pushed
	*/
       public void actionPerformed(ActionEvent event)
          {
	      if(event.getSource() == web)
		  setWebFields();
	      else if( event.getSource() == news)
		  setNewsFields();    
	      else if(event.getSource() == okay)
		  execute();
	      else 
		  {
		  this.setVisible(false);
	          this.dispose();
		  }
	  }

       ///////////////////////////////////////////////////////////////
       /**
	*Sets the fields enabled based on the state of the Web Search 
	*check box.
	*/
       public void setWebFields()
          {
	      keywords.setEnabled(web.isSelected());
	      searchEngines.setEnabled(web.isSelected());
	  }
       /**
	*Sets the fields enabled based on the state of the Newsgroup Download 
	*check box.
	*/
       public void setNewsFields()
          {
	      newsServer.setEnabled(news.isSelected());
	      newsGroup.setEnabled(news.isSelected());
	  }
       
       //////////////////////////////////////////////////////////////
       /**
	*This method sends the events to the KernelProxy to be added 
	* to the pool, so that either a web search or news group is 
	*downloaded, or both.
	*/
       public void execute()
          {
	      //just exit if neither are selected.
	      if(!web.isSelected() && !news.isSelected())
		  exit();

	      KernelProxy proxy = KernelProxy.getInstance();
	      if(web.isSelected())
		  {
		    //we need to test if the keywords is empty
		    if(keywords.getText().equals(""))
		      {
			JOptionPane.showMessageDialog(this,"Please fill out the keywords , or select Cancel", "Keywords not filled out...", JOptionPane.ERROR_MESSAGE);
			//then we need them to go back and fill out the info
			return;
		      }
     
		      proxy.addEvent(
                            new WebSearchEvent(proxy.getEventGenerator(),
					       keywords.getText(),
					       getSearchEngine()));
		    
		  }
	      if(news.isSelected())
		  {
		    //check to see if the news group fields are blank
		    if(newsGroup.getText().equals("") ||
		       newsServer.getText().equals(""))
		      {
			JOptionPane.showMessageDialog(this, "Please fill out newgroup and server information, or select Cancel", "Newgroup information incomplete...", JOptionPane.ERROR_MESSAGE);
			//return for them to enter the needed info
			return;
		      }
						      
		      proxy.addEvent(
		        new NewsGroupDownloadEvent(proxy.getEventGenerator(),
						    newsGroup.getText(),
						    newsServer.getText()));
		     
		  }
	      //if we get to here then then we have already done our searchs
	      // so we need to exit the window.
	      exit();
	  } 
       //////////////////////////////////////////////////////////////
       /**
	*Returns the search engine selected by the user.
	*@return The selected search engine.
	*/
       public String getSearchEngine()
          {
	      int index = searchEngines.getSelectedIndex();
	      return engines[index];
	  }
	
       //////////////////////////////////////////////////////////////
       public void exit()
          {
	      this.setVisible(false);
	      // this.dispose();
	  }
}
		    
		     
	   
