package org.datamanager.userinterface.cerulean.view.search;

import org.datamanager.userinterface.cerulean.Cerulean;
import org.datamanager.userinterface.cerulean.model.data.storage.InterfaceEntityList;
import org.datamanager.userinterface.cerulean.model.InterfaceCluster;
import org.datamanager.userinterface.cerulean.model.InterfaceClusterManager;
import org.datamanager.userinterface.cerulean.model.kernel.KernelProxy;
import org.datamanager.constraint.EntityConstraint;
import org.datamanager.constraint.NameEqualsConstraint;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.JButton;
import java.awt.Dimension;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import org.datamanager.userinterface.cerulean.view.search.AdvancedSearchFrame;

/**
 *This class allows the user to do searchs inside of Cerulean.  The can type 
 *keywords into the JTextField and press the Search button.  This class then 
 *tells KernelProxy to do a search with the keywords.  And KernelProxy
 *returns a list of all the InterfaceEntitys with names containing the
 *keywords.  If, however, the "advanced" button is pressed an
 *AdvancedSearchFrame is displayed.  For more information on what that does
 * see the class AdvancedSearchFrame in this same package. 
 *
 *@author Bryan Dawson (bdawson@indiana.edu)
 *@author Gordon Murphy (gpmurphy@indiana.edu)
 * 
 *@see org.datamanager.userinterface.cerulean.model.kernel.KernelProxy
 *@see org.datamanager.userinterface.cerulean.view.search.AdvancedSearchFrame
 */
//  Methods
//  ~~~~~~~
//  public SearchPane()
//      	Creates a new SearchPane that listens for its own button pushes
//  public void ActionPerformed(ActionEvent)
//  	Takes the text from the text field and as long as the string is not
//  	the empty string, then it passes the string on to the KernelProxy
//  	to do the actual searching
//////////////////////////////////////////////////////////////

public class SearchPane extends JPanel implements ActionListener
   {
   //to enter in the keywords
   private JTextField text;
    
   //The options
   private JButton search, advanced;
   
   //////////////////////////////////////////////////////////
   /**
    *The only constructor.  Sets up the gui and adds this class as
    *an ActionListener for the JTextField and the two JButtons.
    */
   public SearchPane()
      {
      setPreferredSize(new Dimension(200, 80));
      setOpaque(false);
      
      //create the elements
      text = new JTextField(10);
      search = new JButton("Search");
      advanced = new JButton("advanced");
      
      //add the listeners
      text.addActionListener(this);
      search.addActionListener(this);
      advanced.addActionListener(this);
      
      //add them
      add(text);
      add(search);
      add(advanced);
      }
   
   ///////////////////////////////////////////////////////////////////   
   /**
    *Determines if this was a normal search (event came from the JTextField 
    *or the "search" button) or an advanced search (event came from the 
    *"advanced" button.  Then either asks the KernelProxy to do a search wiht
    *the text from the JTextField, or it displays an AdvancedSearchFrame.
    *@param event Fired from either the JTextField or one of the two buttons.
    */
   public void actionPerformed(ActionEvent event)
      {
      if(event.getSource() == text || event.getSource() == search)
         {
         String keywords = text.getText();
         if(!keywords.equals(""))
             {
             InterfaceEntityList list = KernelProxy.getInstance().searchByName(keywords);
             InterfaceCluster search = InterfaceClusterManager.getInstance().getSearchCluster();
             search.addEntities(list);
             search.setSelected(this);
             }
          }
      if(event.getSource() == advanced)
	  {
	      new AdvancedSearchFrame(text.getText()).show();
	  }
       }
   }
