package org.datamanager.userinterface.cerulean.view.tree;

import org.datamanager.userinterface.cerulean.view.tree.InterfaceTreeCellRenderer;
import org.datamanager.userinterface.cerulean.model.tree.EntityTreeModel;
import org.datamanager.userinterface.cerulean.controller.tree.ClickHandler;
import javax.swing.JTree;

/**
 *This class is used to display the entities that from selected clusters.  When
 *the user selects a cluster an event is sent to the ClusterListener registered
 *for model of this class.  That listener then tells the model to build a node
 *who's childern are the entities of the cluster.  When the user unselects that
 *cluster an event is again sent to the ClusterListener, who tells the the
 *model to remove the node corresponding to the cluster from the tree.
 *Selection is handled by another class, SectionHandler.
 *
 *@author Bryan Dawson (bdawson@indiana.edu)
 *@author Gordon Murphy (gpmurphy@indiana.edu)
 *
 *@see org.datamanager.userinterface.cerulean.view.tree.InterfaceTreeCellRenderer
 *@see org.datamanager.userinterface.cerulean.controller.tree.ClusterSelectionListener
 *@see org.datamanager.userinterface.cerulean.controller.tree.ClickHandler
 *@see org.datamanager.userinterface.cerulean.model.tree.EntityTreeModel
 *@see org.datamanager.userinterface.cerulean.model.tree.EntityNode
 *@see org.datamanager.userinterface.cerulean.model.tree.ClusterNode
 */ 
//  Methods:
//  ~~~~~~~~
//  public EntityTree()
//          The only constructor.  Delegates the work of control over to the 
//          model and cell renderer.  The model works with the
//          ClusterSectionListener to control the make up of the tree.  The
//          cell renderer controls the look of the tree.
//////////////////////////////////////////////////////////////////////

public class EntityTree extends JTree
   {
   private EntityTreeModel treeModel;
   private InterfaceTreeCellRenderer cellRenderer;

   ////////////////////////////////////////////////////////
   /**
    *The only constructor.  Delegates the work of control over to the 
    *model and cell renderer.  The model works with the
    *ClusterSectionListener to control the make up of the tree.  The
    * cell renderer controls the look of the tree.
    */
   public EntityTree()
        {
        super();
        treeModel = new EntityTreeModel(this);
        cellRenderer = new InterfaceTreeCellRenderer();

        this.setModel(treeModel);
        this.setCellRenderer(cellRenderer);

        //set it up so that lines connect the entities to the cluster
        putClientProperty("JTree.lineStyle", "Angled");
       
        this.addMouseListener(new ClickHandler(this));

        this.setOpaque(false);
        }
   }




 

  


