package org.datamanager.userinterface.cerulean.view.viewer;

import org.datamanager.passiveentityvalue.PassiveEntityValue;
import org.datamanager.passiveentityvalue.ObjectEntityValue;
import org.datamanager.passiveentityvalue.IntegerEntityValue;
import org.datamanager.userinterface.cerulean.model.InterfaceEntity;
import org.datamanager.userinterface.cerulean.model.InterfaceAttribute;

import javax.swing.JFrame;
import javax.swing.JEditorPane;
import javax.swing.JScrollPane;

import java.awt.BorderLayout;

/**
A simple browser that displays a mail message's subject, sender,
message body (for plain text messages only), and other attributes.
**/
public class MailViewer
	extends JFrame
	{
	private InterfaceEntity mailMessage;

	public final static int WINDOW_WIDTH = 600;
	public final static int WINDOW_HEIGHT = 480;

	/**
	Initialize a new MailViewer to display a window
	containing an email message.
	**/
	public MailViewer(InterfaceEntity mailMessage)
		{
		JEditorPane editorPane = new JEditorPane();
		JScrollPane pane = new JScrollPane(editorPane);
		getContentPane().setLayout(new BorderLayout());
		getContentPane().add(pane, BorderLayout.CENTER);
		setSize(MailViewer.WINDOW_WIDTH, MailViewer.WINDOW_HEIGHT);

		this.mailMessage = mailMessage;
		String messageText = getText();
		editorPane.setText(messageText);
		super.setVisible(true);
		}

	//needed until we can decide what to do in EmailEntityComponent...
	public void setVisible(boolean visible)
		{ }

	/**
	Report a string containing the text of the email message.
	**/
	private String getText()
		{
		String text =
			"Sender(s): " + getString("email senders") + "\n" +
			"Recipient(s): " + getString("email recipients") + "\n" +
			"Subject: " + getString("email subject") + "\n" +
			"Date: " + getString("email date") + "\n" +
			"Size: " + getInteger("email size") + "\n" +
			"Content Type: " + getString("email content type") + "\n\n" +
			getMessageBody("email message body");

		return text;
		}

	/**
	Report an int representation of the IntegerEntityValue
	stored in the named attribute of the mail message.
	NOTE: unnecessary code duplication in the next three get methods.
	Perhaps PassiveEntityValue should have a getDisplayableString().
	**/
	private int getInteger(String attributeName)
		{
		InterfaceAttribute attribute =
			mailMessage.getAttribute(attributeName);
		IntegerEntityValue attributeValue =
			(IntegerEntityValue) attribute.getValue();

		return attributeValue.getCeiling(); //NOTE: bad IEV method!
		}

	/**
	/**
	Report a String representation of the PassiveEntityValue
	stored in the named attribute of the mail message.
	**/
	private String getString(String attributeName)
		{
		InterfaceAttribute attribute =
			mailMessage.getAttribute(attributeName);
		PassiveEntityValue attributeValue =
			(PassiveEntityValue) attribute.getValue();

		return attributeValue.toString();
		}

	/**
	Report a String representation of the mail message's body.
	**/
	private String getMessageBody(String attributeName)
		{
		InterfaceAttribute attribute =
			mailMessage.getAttribute(attributeName);
		ObjectEntityValue objectValue =
			(ObjectEntityValue) attribute.getValue();

		Object object = objectValue.getObject();
		String messageBody = "";
		if (object instanceof String)
			messageBody = (String) object;

		return messageBody;
		}
	}
