import org.datamanager.tools.Information;
import org.datamanager.constraint.*;
import org.datamanager.event.*;
import org.datamanager.exception.DataManagerException;
import org.datamanager.tools.Debug;
import org.datamanager.kernel.Entity;
import org.datamanager.kernel.Simpleton;
import org.datamanager.kernel.*;
import org.datamanager.passiveentityvalue.*;

import org.datamanager.collector.tools.NewsConnection;

import java.io.IOException;
import java.net.UnknownHostException;
import java.util.StringTokenizer;
import java.util.Enumeration;
import java.util.Vector;

/**
This Simpleton's job is to go to a news group and download a
list of articles. Those articles are then sent of in
NewsMessageDownloadEvents to be downloaded by another simpleton.
**/

public class NewsGroupDownloadSimpleton
	extends Simpleton
	implements EventHandler
	{
		/*
		Author: Matthew Farrellee <mafarrel@cs.indiana.edu>
		
		API:
		public NewsGroupLocatorSimpleton()
			Creates a new NewsGroupDownloadSimpleton.
		*/

	public NewsGroupDownloadSimpleton()
		{
		}

	public Information getInformation()
		{
		String[] authors = {""};
		return new Information("NewsGroupDownloadSimpleton",
										"short", "long", "version", authors);
		}

	public void process()
		{
		try
			{
			EventConstraint eventFilter =
				new EventTypeIsConstraint(NewsGroupDownloadEvent.class);
			Pool.getDefaultPool().subscribe(this, eventFilter);
			}
		catch (DataManagerException exception)
			{
			// This doesnt happen in Hydrogen.
			}
		}

	public void handle(DataManagerEvent event)
		{
		NewsGroupDownloadEvent download = (NewsGroupDownloadEvent) event;
		download(download.getServer(), download.getNewsGroup());
		}


	////////////////////////////////////////////////////////////////////

	/**
	**/

	protected void download(String address, String group)
		{
		try
			{
			NewsConnection server = NewsConnection.getConnection();

			boolean check;
			
			// This method initialized the output and input
			// streams. This could potentially cause an
			// UnknownHostException or an IOException.
			check = server.connect(address);
			Debug.assert(check, "Failed to connect to: " + address);
			
			// Change to the correct news group. This could
			// cause an IOException.
			check = server.group(group);
			Debug.assert(check, "Failed to select group: " + group);
			

			String headers;
			String body;
			String messageID;

			int count = 1;

			do // Begin Do-While loop.
				{
				messageID = server.getCurrentMessage();
				headers = server.head();
				body = server.body();

				// Extract the Subject from the headers.
				int startSubject = headers.indexOf("Subject: ");
				//System.err.println("'count' == " + count++);
				//System.err.println("'Subject: ' located at: " + startSubject);
				//System.err.println("'headers' == " + headers);
				//System.err.println("'messageID' == " + messageID);
				//System.err.println("'body' == " + body);
				//System.err.println("location of \\n after Subject: " +
				//	headers.substring(startSubject,
				//							headers.length()).indexOf("\n"));

				String subject =
					headers.substring(startSubject + 9,
								headers.substring(startSubject,
											headers.length()).indexOf("\n") + startSubject);

				//System.err.println("subject == " + subject);

				try
					{
					Entity message = Entity.create(subject);
					Entity headerAttribute = Entity.create("Headers");
					Entity serverAttribute = Entity.create("NewsGroupServer");
					Entity groupAttribute = Entity.create("NewsGroup");
					Entity contentAttribute = Entity.create("content-source");
					Entity mimeAttribute = Entity.create("mime-type");

					headerAttribute.setValue(new StringEntityValue(headers));
					serverAttribute.setValue(new StringEntityValue(address));
					groupAttribute.setValue(new StringEntityValue(group));
					message.setValue(new StringEntityValue(body));
					contentAttribute.setValue(new StringEntityValue("news"));
					mimeAttribute.setValue(new StringEntityValue("text/plain"));

					message.attach(headerAttribute);
					message.attach(serverAttribute);
					message.attach(groupAttribute);
					message.attach(contentAttribute);
					message.attach(mimeAttribute);

					Pool.getDefaultPool().add(message);

					
					DocumentDownloadedEvent downloadEvent = new DocumentDownloadedEvent(Pool.getDefaultPool(), message);
					Pool.getDefaultPool().add(downloadEvent);
					}
				catch (DataManagerException problem)
					{
					// Not sure what should happen here.
					// This should never happen with Hydrogen.
					}
				}
			while (server.next()); // End Do-While loop.

			}
		catch (UnknownHostException badHostName)
			{
			badHostName.printStackTrace();
			// No host to connect to. Just forget about this entity.
			Debug.assert("Problem locating news server, skipping " +
							 "this entity: " + badHostName.getMessage());
			}
		catch (IOException ioError)
			{
			ioError.printStackTrace();
			// There was some sort of problem while reading from
			// a connection to the server. Just forget about this
			// entity, it must have bad attributes.
			Debug.assert("Problem reading/writing from/to the news " +
							 "server, skipping entity: " +
							 ioError.getMessage());
			}
		}

	} // End of the NewsGroupLocatorSimpleton.package org.datamanager.collectors.simpleton.news;
