import org.datamanager.kernel.*;
import org.datamanager.constraint.*;
import org.datamanager.passiveentityvalue.*;
import org.datamanager.exception.*;
import org.datamanager.tools.*;

import org.datamanager.tools.Debug;

public class PoolSanitySimpleton extends SanitySimpleton
	{
	public PoolSanitySimpleton()
		{
		}

	public void sanityTestSuite()
		throws DataManagerException
		{
		Pool pool = Pool.getDefaultPool();
		Debug.assert("PSS: getDefaultPool() returns: " + pool);
		Entity entity1 = Entity.create("entity1");
		Debug.assert("PSS: created entity1: " + entity1);
		Entity entity2 = Entity.create("entity2");
		Debug.assert("PSS: created entity2: " + entity2);

		pool.add(entity1);
		pool.add(entity2);
		Debug.assert("PSS: added entity1 and entity2 to the pool");

		Debug.assert("PSS: searching pool with Constraint.NONE");
		long time1, time2;
		time1 = System.currentTimeMillis();
		Entity[] entities = pool.search(EntityConstraint.NONE);
		time2 = System.currentTimeMillis();
		Debug.assert("PSS: search took: " + (time2 - time1) +
					" milliseconds");
		Debug.assert("PSS: search complete, returned: " + entities);

		for (int index = 0; index < entities.length; index++)
			{
			Debug.assert("PSS: entities[" + index + "] = " + entities[index]);
			}

		Entity tempEntity;
		for (int count = 1000; count > 0; count--)
			{
			tempEntity = Entity.create("entity" + count);
			tempEntity.setValue(new DoubleEntityValue(count));
			pool.add(tempEntity);
			}
		time2 = System.currentTimeMillis();
		Debug.assert("PSS: added 1,000 Entities to the pool: " + (time2 - time1));
	
		Debug.assert("PSS: searching pool with " + 
					"And 2-ValueInRangeConstraint");
		time1 = System.currentTimeMillis();
		entities = pool.search(
			new AndConstraint(new ValueInRangeConstraint(45, 8000),
									new ValueInRangeConstraint(600, 9000)));
		time2 = System.currentTimeMillis();
		Debug.assert("PSS: search took: " + (time2 - time1) +
					" milliseconds");
		Debug.assert("PSS: search complete, returned: " + entities);

		Debug.assert("PSS: First 15 entities returned:");

		for (int index = 0; index < 15; index++)
			{
			Debug.assert("PSS: entities[" + index + "] = " +
						entities[index]);
			}
		Debug.assert("PSS: search took: " + (time2 - time1) +
					" milliseconds");
		}

	public Information getInformation()
		{
		String name = "PoolSanitySimpleton";
		String shortDescription =
			"Tests the sanity of the default pool.";
		String longDescription =
			"This simpleton adds a large number of entities " +
			"to the default pool and then tests to see if they " +
			"are all there.";
		String version = "1.0";
		String[] authors = {"Ben Keil", "Matthew Farrellee"};
		return new Information(
			name,
			shortDescription,
			longDescription,
			version,
			authors);
		}
	}
