import org.datamanager.collector.tools.WebConnection;
import org.datamanager.passiveentityvalue.*;
import org.datamanager.constraint.*;
import org.datamanager.exception.*;
import org.datamanager.event.*;
import org.datamanager.kernel.*;
import org.datamanager.kernel.Simpleton;
import org.datamanager.kernel.Entity;
import org.datamanager.tools.Information;
import org.datamanager.constraint.AttributeExistsConstraint;
import org.datamanager.constraint.AndConstraint;
import org.datamanager.constraint.NotConstraint;
import org.datamanager.tools.Debug;

import java.net.URL;
import java.io.IOException;


	/**
	This Simpleton has the job of downloading a URL.
	<p>
	It looks for Entities that have a URL Attribute, and when
	a valid Entity is found this Simpleton takes the URL stored
	in the Entity and downloads the contents of that URL. This
	contents is stored in the contents attribute which is added to
	the Entity being processed.
	**/


public class WebPageDownloadSimpleton
	extends Simpleton
	implements EventHandler
	{
	/*
	Author: Matt Farrellee <mafarrel@cs.indiana.edu>
	Editors: none
	Reviewers: none
	

	API:
	*/

	private static EntityConstraint undownloadedEntity =
		new AndConstraint(
			new AttributeExistsConstraint(
				new NameEqualsConstraint("content-location")),
			new AndConstraint(
				(EntityConstraint)
				new NotConstraint(
					new AttributeExistsConstraint(
						new NameEqualsConstraint("mime-type"))),
				(EntityConstraint)
				new NotConstraint(
					new AttributeExistsConstraint(
						new NameEqualsConstraint("content-source")))));


	////////////////////////////////////////////////////////////////////

	/**
	This is the default constructor. It calls the constructor that takes
	a String with a default name.
	**/

	public WebPageDownloadSimpleton()
		{
		}

	////////////////////////////////////////////////////////////////////

	public Information getInformation()
		{
		String[] authors = {""};
		return new Information("WebPageDownloadSimpleton",
										"short", "long", "version", authors);
		}

	////////////////////////////////////////////////////////////////////

	/**
	This method is where all the Simpleton's processing takes place.
	First the entity is downloaded and then written to the InfoPool.
	The entity is downloaded withthe downloadEntity() method. That
	method is destructive in order to take advantage of the entity
	that already exists. Instead of creating a new Entity to put in
	the InfoPool it just adds onto the entity that is being processed.
	
	@param entity The entity to process.
	**/

	public void process()
		{
		try
			{
			AddedEntitySatisfiesConstraint constraint =
				new AddedEntitySatisfiesConstraint(undownloadedEntity);
			Pool.getDefaultPool().subscribe(this, constraint);
			}
		catch (DataManagerException exception)
			{
			}
		}


	public void handle(DataManagerEvent event)
		{
		try
			{
			WebConnection connection = WebConnection.getConnection();

			AddEntityEvent addEvent = (AddEntityEvent) event;
		
			Entity addedEntity = addEvent.getAddedEntity();

			Entity[]	attributes = addedEntity.getAttributes(
				new NameEqualsConstraint("content-location"));

			if (attributes.length > 0)
				{
				String url = attributes[0].getValue().toString();
				// getContentsFromURL can throw an IOException.
				// Turn the URL into a String. Not the actual URL itself,
				// but rather the contents that it points to. Usually a
				// web page.
				String contents = connection.getContents(new URL(url));
		
				// Add this new contents to the entity.
				//entity.addAttribute(contentAttribute, contents, getID());			

				Entity mimeType = Entity.create("mime-type");
				Entity contentSource = Entity.create("content-source");

				mimeType.setValue(new StringEntityValue("text/html"));
				contentSource.setValue(new StringEntityValue("www"));
				
				addedEntity.setValue(new StringEntityValue(contents));
				
				addedEntity.attach(mimeType);
				addedEntity.attach(contentSource);

				DocumentDownloadedEvent downloadEvent = new DocumentDownloadedEvent(Pool.getDefaultPool(), addedEntity);
				Pool.getDefaultPool().add(downloadEvent);
				

				}
			}
		catch (DataManagerException exception)
			{
			}
		// If there is trouble getting the contents from the URL.
		catch (IOException ioError)
			{
			// Signal that there was a problem with an assertion.
			Debug.assert("Got an IOException: " + ioError.getMessage());
			}
		}

	} // End of UrlDownloadSimpleton class.
